@@ -66,13 +66,36 @@ SWModule_ptr SWMgr_impl::getModuleByName(const char *name) throw(CORBA::SystemEx
 
 
 StringList *SWMgr_impl::getGlobalOptions() throw(CORBA::SystemException) {
+	sword::StringList options = delegate->getGlobalOptions();
+	StringList *retVal = new StringList;
+	int count = 0;
+	for (sword::StringList::iterator it = options.begin(); it != options.end(); it++) {
+		count++;
+	}
+	retVal->length(count);
+	count = 0;
+	for (sword::StringList::iterator it = options.begin(); it != options.end(); it++) {
+		(*retVal)[count++] = CORBA::string_dup(it->c_str());
+	}
+	return retVal;
 }
 
 
 StringList *SWMgr_impl::getGlobalOptionValues(const char *option) throw(CORBA::SystemException) {
+	sword::StringList options = delegate->getGlobalOptionValues(option);
+	StringList *retVal = new StringList;
+	int count = 0;
+	for (sword::StringList::iterator it = options.begin(); it != options.end(); it++) {
+		count++;
+	}
+	retVal->length(count);
+	count = 0;
+	for (sword::StringList::iterator it = options.begin(); it != options.end(); it++) {
+		(*retVal)[count++] = CORBA::string_dup(it->c_str());
+	}
+	return retVal;
 }
 
-
 void SWMgr_impl::terminate() throw(CORBA::SystemException) {
 	exit(0);
 }
@@ -92,7 +115,7 @@ char *SWModule_impl::getCategory() throw(CORBA::SystemException) {
 }
 
 
-StringList *SWModule_impl::search(const char *istr, SearchType searchType, CORBA::Long flags, const char *scope) throw(CORBA::SystemException) {
+SearchHitList *SWModule_impl::search(const char *istr, SearchType searchType, CORBA::Long flags, const char *scope) throw(CORBA::SystemException) {
 	int stype = 2;
 	sword::ListKey lscope;
 	sword::VerseKey parser;
@@ -107,13 +130,48 @@ StringList *SWModule_impl::search(const char *istr, SearchType searchType, CORBA
 	}
 	else	result = delegate->Search(istr, stype, flags);
 
-	StringList *retVal = new StringList;
+	SearchHitList *retVal = new SearchHitList;
 	int count = 0;
 	for (result = sword::TOP; !result.Error(); result++) count++;
 	retVal->length(count);
 	int i = 0;
-	for (result = sword::TOP; !result.Error(); result++)
-		(*retVal)[i++] = CORBA::string_dup((const char *)result);
+	for (result = sword::TOP; !result.Error(); result++) {
+		(*retVal)[i].modName = CORBA::string_dup(delegate->Name());
+		(*retVal)[i].key = CORBA::string_dup((const char *)result);
+		(*retVal)[i++].score = (long)result.getElement()->userData;
+	}
+
+	return retVal;
+}
+
+
+
+StringList *SWModule_impl::getEntryAttribute(const char *level1, const char *level2, const char *level3) throw(CORBA::SystemException) {
+	delegate->RenderText();	// force parse
+	sword::AttributeTypeList &entryAttribs = delegate->getEntryAttributes();
+	sword::AttributeTypeList::iterator i1 = entryAttribs.find(level1);
+	sword::AttributeList::iterator i2;
+	sword::AttributeValue::iterator i3, j3;
+	StringList *retVal = new StringList;
+	int count = 0;
+
+	if (i1 != entryAttribs.end()) {
+		i2 = i1->second.find(level2);
+		if (i2 != i1->second.end()) {
+			i3 = i2->second.find(level3);
+			if (i3 != i2->second.end()) {
+				for (j3 = i3; j3 != i2->second.end(); j3++)
+					count++;
+				retVal->length(count);
+				count = 0;
+				for (j3 = i3; j3 != i2->second.end(); j3++) {
+					(*retVal)[count++] = CORBA::string_dup(i3->second.c_str());
+				}
+			}
+		}
+	}
+	if (!count)
+		retVal->length(count);
 
 	return retVal;
 }
@@ -126,13 +184,25 @@ StringList *SWModule_impl::getKeyChildren() throw(CORBA::SystemException) {
 
 	sword::VerseKey *vkey = SWDYNAMIC_CAST(VerseKey, key);
 	if (vkey) {
-		retVal->length(2);
+		retVal->length(6);
 		SWBuf num;
-		num.appendFormatted("%d", vkey->books[vkey->Testament()-1][vkey->Book()-1].chapmax);
+		num.appendFormatted("%d", vkey->Testament());
 		(*retVal)[0] = CORBA::string_dup(num.c_str());
 		num = "";
-		num.appendFormatted("%d", vkey->books[vkey->Testament()-1][vkey->Book()-1].versemax[vkey->Chapter()-1]);
+		num.appendFormatted("%d", vkey->Book());
 		(*retVal)[1] = CORBA::string_dup(num.c_str());
+		num = "";
+		num.appendFormatted("%d", vkey->Chapter());
+		(*retVal)[2] = CORBA::string_dup(num.c_str());
+		num = "";
+		num.appendFormatted("%d", vkey->Verse());
+		(*retVal)[3] = CORBA::string_dup(num.c_str());
+		num = "";
+		num.appendFormatted("%d", vkey->books[vkey->Testament()-1][vkey->Book()-1].chapmax);
+		(*retVal)[4] = CORBA::string_dup(num.c_str());
+		num = "";
+		num.appendFormatted("%d", vkey->books[vkey->Testament()-1][vkey->Book()-1].versemax[vkey->Chapter()-1]);
+		(*retVal)[5] = CORBA::string_dup(num.c_str());
 	}
 	else {
 		TreeKeyIdx *tkey = SWDYNAMIC_CAST(TreeKeyIdx, key);
