@@ -1,7 +1,7 @@
 /******************************************************************************
  * canon.h - Canonical text information to be included by VerseKey.cpp
  *
- * $Id: canon.h,v 1.13 2002/06/25 04:17:29 chrislit Exp $
+ * $Id: canon.h,v 1.19 2003/07/04 21:45:24 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,6 +24,9 @@
  *		and chapmax
  */
 
+#include <defs.h>
+//SWORD_NAMESPACE_START
+
 struct sbook
   VerseKey::otbooks[] = {
   {"Genesis", "Gen", 50},
@@ -34,17 +37,17 @@ struct sbook
   {"Joshua", "Josh", 24},
   {"Judges", "Judg", 21},
   {"Ruth", "Ruth", 4},
-  {"I Samuel", "I Sam", 31},
-  {"II Samuel", "II Sam", 24},
-  {"I Kings", "I Kin", 22},
-  {"II Kings", "II Kin", 25},
-  {"I Chronicles", "I Chr", 29},
-  {"II Chronicles", "II Chr", 36},
+  {"I Samuel", "1Sam", 31},
+  {"II Samuel", "2Sam", 24},
+  {"I Kings", "1Kgs", 22},
+  {"II Kings", "2Kgs", 25},
+  {"I Chronicles", "1Chr", 29},
+  {"II Chronicles", "2Chr", 36},
   {"Ezra", "Ezra", 10},
   {"Nehemiah", "Neh", 13},
   {"Esther", "Esth", 10},
   {"Job", "Job", 42},
-  {"Psalms", "Psa", 150},
+  {"Psalms", "Ps", 150},
   {"Proverbs", "Prov", 31},
   {"Ecclesiastes", "Eccl", 12},
   {"Song of Solomon", "Song", 8},
@@ -69,31 +72,31 @@ struct sbook
 
 struct sbook
   VerseKey::ntbooks[] = {
-  {"Matthew", "Mat", 28},
+  {"Matthew", "Matt", 28},
   {"Mark", "Mark", 16},
   {"Luke", "Luke", 24},
   {"John", "John", 21},
   {"Acts", "Acts", 28},
   {"Romans", "Rom", 16},
-  {"I Corinthians", "I Cor", 16},
-  {"II Corinthians", "II Cor", 13},
+  {"I Corinthians", "1Cor", 16},
+  {"II Corinthians", "2Cor", 13},
   {"Galatians", "Gal", 6},
   {"Ephesians", "Eph", 6},
-  {"Philippians", "Philip", 4},
+  {"Philippians", "Phil", 4},
   {"Colossians", "Col", 4},
-  {"I Thessalonians", "I Thes", 5},
-  {"II Thessalonians", "II Thes", 3},
-  {"I Timothy", "I Tim", 6},
-  {"II Timothy", "II Tim", 4},
+  {"I Thessalonians", "1Thess", 5},
+  {"II Thessalonians", "2Thess", 3},
+  {"I Timothy", "1Tim", 6},
+  {"II Timothy", "2Tim", 4},
   {"Titus", "Titus", 3},
-  {"Philemon", "Philem", 1},
+  {"Philemon", "Phlm", 1},
   {"Hebrews", "Heb", 13},
   {"James", "Jas", 5},
-  {"I Peter", "I Pet", 5},
-  {"II Peter", "II Pet", 3},
-  {"I John", "I Jo", 5},
-  {"II John", "II Jo", 1},
-  {"III John", "III Jo", 1},
+  {"I Peter", "1Pet", 5},
+  {"II Peter", "2Pet", 3},
+  {"I John", "1John", 5},
+  {"II John", "2John", 1},
+  {"III John", "3John", 1},
   {"Jude", "Jude", 1},
   {"Revelation of John", "Rev", 22}
 };
@@ -278,13 +281,14 @@ const struct abbrev
   {"PHIL", 50},			//    Philippians
   {"PHILEMON", 57},		// Philemon
   {"PHILIPPIANS", 50},		// Philippians
+  {"PHLM", 57},		// Philemon
   {"PHM", 57},			//   Philemon
   {"PHP", 50},			//   Philippians
   {"PROVERBS", 20},		//    Proverbs
   {"PSALMS", 19},		//    Psalms
   {"PSM", 19},			// Psalms
   {"PSS", 19},			// Psalms
-  {"QOHELETH", 21},              // Qohelot (Ecclesiastes)
+  {"QOHELETH", 21},              // Qohelet (Ecclesiastes)
   {"REVELATION OF JOHN", 66},	//     Revelation
   {"ROMANS", 45},		//    Romans
   {"RUTH", 8},			//    Ruth
@@ -296,7 +300,7 @@ const struct abbrev
   {"TITUS", 56},		//     Titus
   {"ZECHARIAH", 38},		//   Zechariah
   {"ZEPHANIAH", 36},		//   Zephaniah
-  {"", -1}			//   Zephaniah
+  {"", -1}
 };
 
 
@@ -693,3 +697,5 @@ int
   { {sizeof (VerseKey::otbks) / 4, sizeof (VerseKey::otcps) / 4}
 , {sizeof (VerseKey::ntbks) / 4, sizeof (VerseKey::ntcps) / 4}
 };
+
+//SWORD_NAMESPACE_END
