@@ -1,6 +1,6 @@
-/*
+/***************************************************************************
  *
- * $Id: cipherfil.h,v 1.8 2002/07/28 01:48:38 scribe Exp $
+ * $Id: cipherfil.h,v 1.10 2003/02/20 07:25:19 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,15 +24,16 @@
 #include <swfilter.h>
 #include <swcipher.h>
 
-#include <defs.h>
+SWORD_NAMESPACE_START
 
 class SWDLLEXPORT CipherFilter:public SWFilter {
 	SWCipher *cipher;
 public:
 	CipherFilter(const char *key);
 	virtual ~CipherFilter();
-	virtual char ProcessText(char *text, int maxlen, const SWKey *key, const SWModule * = 0);
+	virtual char processText(SWBuf &text, const SWKey *key = 0, const SWModule * = 0);
 	virtual SWCipher *getCipher();
 };
 
+SWORD_NAMESPACE_END
 #endif
