@@ -5,8 +5,8 @@
 #define SWORDDEFS_H
 
 #ifdef NO_SWORD_NAMESPACE
- #define SWORD_NAMESPACE_START
- #define SWORD_NAMESPACE_END
+ #define SWORD_NAMESPACE_START namespace sword {
+ #define SWORD_NAMESPACE_END }; using namespace sword;
 #else
  #define SWORD_NAMESPACE_START namespace sword {
  #define SWORD_NAMESPACE_END }
@@ -15,8 +15,6 @@
 
 SWORD_NAMESPACE_START
 
-#define FILTERPAD 16
-
 // _declspec works in BC++ 5 and later, as well as VC++
 #if defined(_MSC_VER)
 
