@@ -2,6 +2,9 @@
 #define ENTRIESBLK_H
 
 #include <sysdata.h>
+#include <defs.h>
+
+SWORD_NAMESPACE_START
 
 class EntriesBlock {
 	static const int METAHEADERSIZE;
@@ -27,4 +30,5 @@ public:
 };
 
 
+SWORD_NAMESPACE_END
 #endif
