@@ -1,6 +1,6 @@
-/*
+/***************************************************************************
  *
- * $Id: gbfplain.h,v 1.8 2001/12/11 22:35:10 scribe Exp $
+ * $Id: gbfplain.h,v 1.12 2003/02/28 13:31:37 mgruner Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -23,15 +23,15 @@
 
 #include <swfilter.h>
 
-#include <defs.h>
+SWORD_NAMESPACE_START
 
-  /** This filter converts GBF text into plain text
+  /** This filter converts GBF text to plain text
   */
-class SWDLLEXPORT GBFPlain:public SWFilter
-{
+class SWDLLEXPORT GBFPlain : public SWFilter {
 public:
-  GBFPlain ();
-  virtual char ProcessText (char *text, int maxlen, const SWKey *key, const SWModule * = 0);
+	GBFPlain();
+	virtual char processText (SWBuf &text, const SWKey *key = 0, const SWModule *module = 0);
 };
 
+SWORD_NAMESPACE_END
 #endif
