@@ -1,6 +1,6 @@
-/*
+/***************************************************************************
  *
- * $Id: gbfrtf.h,v 1.7 2001/12/11 22:35:10 scribe Exp $
+ * $Id: gbfrtf.h,v 1.10 2003/02/28 13:31:37 mgruner Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -23,15 +23,15 @@
 
 #include <swfilter.h>
 
-#include <defs.h>
+SWORD_NAMESPACE_START
 
-  /** This filter converts GBF text into RTF text
-  */
-class SWDLLEXPORT GBFRTF:public SWFilter
-{
+/** This filter converts GBF text into RTF text
+ */
+class SWDLLEXPORT GBFRTF : public SWFilter {
 public:
-  GBFRTF ();
-  virtual char ProcessText (char *text, int maxlen, const SWKey * key, const SWModule * = 0);
+	GBFRTF();
+	virtual char processText(SWBuf &text, const SWKey *key = 0, const SWModule *module = 0);
 };
 
+SWORD_NAMESPACE_END
 #endif
