@@ -3,7 +3,7 @@
  *			pointing to actual text desired.  Uses standard
  *			files:	ot and nt using indexs ??.bks ??.cps ??.vss
  *
- * $Id: hrefcom.h,v 1.6 2002/07/28 01:48:38 scribe Exp $
+ * $Id: hrefcom.h,v 1.8 2003/02/20 07:25:19 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -29,6 +29,8 @@
 
 #include <defs.h>
 
+SWORD_NAMESPACE_START
+
 class SWDLLEXPORT HREFCom:public RawVerse, public SWCom {
 	char *prefix;
 
@@ -38,7 +40,7 @@ public:
 	HREFCom(const char *ipath, const char *prefix, const char *iname = 0,
 			const char *idesc = 0, SWDisplay * idisp = 0);
 	virtual ~HREFCom();
-	virtual char *getRawEntry();
+	virtual SWBuf &getRawEntryBuf();
 
 	// OPERATORS -----------------------------------------------------------------
 	
@@ -46,5 +48,5 @@ public:
 
 };
 
-
+SWORD_NAMESPACE_END
 #endif
