@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: osishtmlhref.h,v 1.6 2003/08/12 05:36:30 scribe Exp $
+ * $Id: osishtmlhref.h,v 1.8 2003/11/22 05:27:39 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -27,13 +27,14 @@ SWORD_NAMESPACE_START
 
 /** this filter converts OSIS text to HTML text with hrefs
  */
-class SWDLLEXPORT OSISHTMLHref : public SWBasicFilter {
+class SWDLLEXPORT OSISHTMLHREF : public SWBasicFilter {
 private:
 protected:
 	class MyUserData : public BasicFilterUserData {
 	public:
 		bool osisQToTick;
 		bool inBold;
+		SWBuf lastTransChange;
 		SWBuf w;
 		SWBuf fn;
 		MyUserData(const SWModule *module, const SWKey *key);
@@ -43,7 +44,7 @@ protected:
 	}
 	virtual bool handleToken(SWBuf &buf, const char *token, BasicFilterUserData *userData);
 public:
-	OSISHTMLHref();
+	OSISHTMLHREF();
 };
 
 SWORD_NAMESPACE_END
