@@ -2,7 +2,7 @@
  *  rawcom.h   - code for class 'RawCom'- a module that reads raw commentary
  *			files:	ot and nt using indexs ??.bks ??.cps ??.vss
  *
- * $Id: rawcom.h,v 1.15 2002/07/28 01:48:38 scribe Exp $
+ * $Id: rawcom.h,v 1.18 2003/02/20 07:25:19 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -28,20 +28,25 @@
 
 #include <defs.h>
 
+SWORD_NAMESPACE_START
+
 class SWDLLEXPORT RawCom:public RawVerse, public SWCom {
 
+	VerseKey &getVerseKey();
+
+
 public:
-  
     
 	RawCom(const char *ipath, const char *iname = 0, const char *idesc = 0,
 			SWDisplay * idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN,
 			SWTextDirection dir = DIRECTION_LTR, SWTextMarkup markup = FMT_UNKNOWN,
 			const char* ilang = 0);
-     virtual ~RawCom();
-     virtual char *getRawEntry();
+	virtual ~RawCom();
 
-     virtual void increment(int steps);
-     virtual void decrement(int steps) { increment(-steps); }
+	virtual SWBuf &getRawEntryBuf();
+
+	virtual void increment(int steps);
+	virtual void decrement(int steps) { increment(-steps); }
 
 	// write interface ----------------------------
 	virtual bool isWritable() {
@@ -53,9 +58,10 @@ public:
 	virtual void deleteEntry();	// Delete current module entry
 	// end write interface ------------------------
 
-	// OPERATORS -----------------------------------------------------------------
-	
 	SWMODULE_OPERATORS
 
 };
+
+SWORD_NAMESPACE_END
+
 #endif
