@@ -4,7 +4,7 @@
  *			and provides lookup and parsing functions based on
  *			class StrKey
  *
- * $Id: rawstr4.h,v 1.7 2002/07/30 10:17:30 scribe Exp $
+ * $Id: rawstr4.h,v 1.9 2003/02/27 07:39:37 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -26,9 +26,11 @@
 #define RAWSTR4_H
 
 #include <filemgr.h>
-
+#include <swbuf.h>
 #include <defs.h>
 
+SWORD_NAMESPACE_START
+
 class SWDLLEXPORT RawStr4 {
 	static int instance;		// number of instantiated RawStr4 objects or derivitives
 	char *path;
@@ -37,19 +39,20 @@ class SWDLLEXPORT RawStr4 {
 protected:
 	FileDesc *idxfd;
 	FileDesc *datfd;
-	void preptext(char *buf);
-	void setText(const char *key, const char *buf, long len = -1);
-	void linkentry(const char *destkey, const char *srckey);
+	void prepText(SWBuf &buf);
+	void doSetText(const char *key, const char *buf, long len = -1);
+	void doLinkEntry(const char *destkey, const char *srckey);
 public:
 	char nl;
 	RawStr4(const char *ipath, int fileMode = -1);
 	virtual ~RawStr4();
-	void getidxbuf(long ioffset, char **buf);
-	void getidxbufdat(long ioffset, char **buf);
-	signed char findoffset(const char *key, long *start, unsigned long *size,
+	void getIDXBuf(long ioffset, char **buf);
+	void getIDXBufDat(long ioffset, char **buf);
+	signed char findOffset(const char *key, long *start, unsigned long *size,
 	long away = 0, long *idxoff = 0);
-	void readtext(long start, unsigned long *size, char **idxbuf, char **buf);
+	void readText(long start, unsigned long *size, char **idxbuf, SWBuf &buf);
 	static signed char createModule(const char *path);
 };
 
+SWORD_NAMESPACE_END
 #endif
