@@ -2,7 +2,7 @@
  *  rawtext.h   - code for class 'RawText'- a module that reads raw text files:
  *		  ot and nt using indexs ??.bks ??.cps ??.vss
  *
- * $Id: rawtext.h,v 1.27 2003/02/20 07:25:19 scribe Exp $
+ * $Id: rawtext.h,v 1.29 2003/08/29 19:02:44 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -29,12 +29,27 @@
 
 #include <defs.h>
 
+#ifdef USELUCENE
+namespace lucene { namespace index {
+class IndexReader;
+}}
+
+namespace lucene { namespace search {
+class IndexSearcher;
+}}
+#endif
+
 SWORD_NAMESPACE_START
 
 class SWDLLEXPORT RawText : public SWText, public RawVerse {
 
-	RawStr *fastSearch[2];
 	VerseKey &getVerseKey();
+#ifdef USELUCENE
+	lucene::index::IndexReader *ir;
+	lucene::search::IndexSearcher *is;
+#else
+	RawStr *fastSearch[2];
+#endif
 
 
 public:
@@ -47,7 +62,7 @@ public:
 	virtual void decrement(int steps = 1) { increment(-steps); }
 	virtual signed char createSearchFramework();
 	virtual bool hasSearchFramework() { return true; }
-	virtual ListKey & Search(const char *istr, int searchType = 0, int flags = 0, SWKey * scope = 0, bool * justCheckIfSupported = 0, void (*percent)(char, void *) = &SWModule::nullPercent, void *percentUserData = 0);
+	virtual ListKey &search(const char *istr, int searchType = 0, int flags = 0, SWKey * scope = 0, bool * justCheckIfSupported = 0, void (*percent)(char, void *) = &SWModule::nullPercent, void *percentUserData = 0);
 
 	// write interface ----------------------------
 	virtual bool isWritable() { return ((idxfp[0]->getFd() > 0) && ((idxfp[0]->mode & O_RDWR) == O_RDWR)); }
