@@ -1,7 +1,7 @@
 /******************************************************************************
  *  swcipher.h   - definition of Class SWCipher used for data cipher/decipher
  *
- * $Id: swcipher.h,v 1.6 2001/11/05 07:59:10 chrislit Exp $
+ * $Id: swcipher.h,v 1.8 2003/08/12 10:37:06 scribe Exp $
  *
  * Copyright 1999 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -26,6 +26,8 @@
 
 #include <defs.h>
 
+SWORD_NAMESPACE_START
+
 class SWDLLEXPORT SWCipher
 {
 
@@ -34,16 +36,17 @@ class SWDLLEXPORT SWCipher
 
   char *buf;
   bool cipher;
-  int len;
+  unsigned long len;
 protected:
 public:
     SWCipher (unsigned char *key);
   virtual void setCipherKey (const char *key);
     virtual ~ SWCipher ();
-  virtual char *Buf (const char *buf = 0, unsigned int len = 0);
-  virtual char *cipherBuf (unsigned int *len, const char *buf = 0);
+  virtual char *Buf (const char *buf = 0, unsigned long len = 0);
+  virtual char *cipherBuf (unsigned long *len, const char *buf = 0);
   virtual void Encode (void);
   virtual void Decode (void);
 };
 
+SWORD_NAMESPACE_END
 #endif
