@@ -2,7 +2,7 @@
  *  swconfig.h   - definition of Class SWConfig used for saving and retrieval
  *				of configuration information
  *
- * $Id: swconfig.h,v 1.17 2002/07/28 01:48:38 scribe Exp $
+ * $Id: swconfig.h,v 1.22 2003/06/27 01:41:06 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -25,30 +25,28 @@
 
 #include <stdio.h>
 
-#include <string>
 #include <map>
 
 #include <defs.h>
 #include <multimapwdef.h>
+#include <swbuf.h>
 
-using namespace std;
+SWORD_NAMESPACE_START
 
-
-
-typedef multimapwithdefault < string, string, less < string > >ConfigEntMap;
-typedef map < string, ConfigEntMap, less < string > >SectionMap;
+typedef multimapwithdefault < SWBuf, SWBuf, std::less < SWBuf > >ConfigEntMap;
+typedef std::map < SWBuf, ConfigEntMap, std::less < SWBuf > >SectionMap;
 
 /** The class to read and save settings using a file on disk.
 *
 */
 class SWDLLEXPORT SWConfig {
 private:
-	char getline(FILE * fp, string & line);
+	char getline(FILE * fp, SWBuf & line);
 public:
 	/** The filename used by this SWConfig object
 	*
 	*/
-	string filename;
+	SWBuf filename;
 	/** Map of available sections
 	* The map of available sections.
 	*/
@@ -71,7 +69,7 @@ public:
 	virtual void Save();
 
 	/** Merges the values of addFrom
-	* @param The config which values should be merged to this config object. Already existing values will be overwritten.
+	* @param addFrom The config which values should be merged to this config object. Already existing values will be overwritten.
 	*/
 	virtual void augment(SWConfig &addFrom);
 	virtual SWConfig & operator +=(SWConfig &addFrom) { augment(addFrom); return *this; }
@@ -87,5 +85,5 @@ public:
 	*/
 	virtual ConfigEntMap & operator [](const char *section);
 	};
-
+SWORD_NAMESPACE_END
 #endif
