@@ -1,8 +1,7 @@
 /******************************************************************************
-*  swld.h   - code for base class 'SWLD'.  SWLD is the basis for all
-*				types of Lexicon and Dictionary modules (hence the 'LD').
+*  swgenbook.h
 *
-* $Id: swgenbook.h,v 1.2 2002/07/28 01:48:38 scribe Exp $
+* $Id: swgenbook.h,v 1.5 2003/03/04 22:32:55 mgruner Exp $
 *
 * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
 *	CrossWire Bible Society
@@ -28,8 +27,9 @@
 
 #include <defs.h>
 
-/** the basis for all types of Lexicon and
-* Dictionary modules (hence the 'LD').
+SWORD_NAMESPACE_START
+
+/** The basis for all Book modules.
 */
 class SWDLLEXPORT SWGenBook : public SWModule {
 
@@ -37,11 +37,7 @@ protected:
 	char *entkeytxt;
 
 public:
-	/** Initializes data for instance of SWLD
-	*
-	* @param imodname Internal name for module
-	* @param imoddesc Name to display to user for module
-	* @param idisp Display object to use for displaying
+	/** Initializes data for instance of SWGenBook
 	*/
 	SWGenBook(const char *imodname = 0, const char *imoddesc = 0,
 			SWDisplay * idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN,
@@ -58,4 +54,5 @@ public:
 
 };
 
+SWORD_NAMESPACE_END
 #endif
