@@ -2,7 +2,7 @@
  *  swlocale.h   - definition of Class SWLocale used for retrieval
  *				of locale lookups
  *
- * $Id: swlocale.h,v 1.7 2002/07/28 01:48:38 scribe Exp $
+ * $Id: swlocale.h,v 1.11 2003/06/27 01:41:06 scribe Exp $
  *
  * Copyright 2000 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -23,7 +23,6 @@
 #ifndef SWLOCALE_H
 #define SWLOCALE_H
 
-#include <string>
 #include <map>
 
 #include <swconfig.h>
@@ -31,9 +30,9 @@
 
 #include <defs.h>
 
-using namespace std;
+SWORD_NAMESPACE_START
 
-typedef map < string, string, less < string > >LookupMap;
+typedef std::map < SWBuf, SWBuf, std::less < SWBuf > >LookupMap;
 
 /** SWLocale is used for the localisation of the booknames
 * The SWLocale is a class which holds the information of one language.
@@ -70,4 +69,5 @@ public:
 	virtual void getBooks(char **iBMAX, struct sbook ***ibooks);
 };
 
+SWORD_NAMESPACE_END
 #endif
