@@ -2,7 +2,7 @@
 *  swmgr.h   - definition of class SWMgr used to interact with an install
 *				base of sword modules.
 *
-* $Id: swmgr.h,v 1.45 2002/08/08 21:35:05 scribe Exp $
+* $Id: swmgr.h,v 1.55 2003/07/05 04:58:42 scribe Exp $
 *
 * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
 *	CrossWire Bible Society
@@ -20,7 +20,7 @@
 *
 */
 
-/** @mainpage The Sword Project 1.5.3 - API documentation
+/** @mainpage The Sword Project - API documentation
 * This is the API documentation of the Sword project.
 * it describes the structure of the Sword library and documents the functions of the classes.
 * From time to time this documentation gives programming examples, too.
@@ -33,14 +33,13 @@
 * Well knwon frontends are:\n
 *	-BibleCS for Windows (the sourcecode is availble in the CVS of crosswire.org)\n
 *	-GnomeSword (http://gnomesword.sourceforge.net/)\n
-*	-BibleTime (http://www.bibletime.de/)\n
+*	-BibleTime (http://www.bibletime.info/)\n
 */
 
 #ifndef SWMGR_H
 #define SWMGR_H
 
 #include <sys/types.h>
-#include <string>
 #include <map>
 #include <list>
 #include <swmodule.h>
@@ -50,11 +49,11 @@
 
 #include <defs.h>
 
-using namespace std;
+SWORD_NAMESPACE_START
 
-typedef map < string, SWModule *, less < string > >ModMap;
-typedef list < string > OptionsList;
-typedef map < string, SWFilter * >FilterMap;
+typedef std::map < SWBuf, SWModule *, std::less < SWBuf > >ModMap;
+typedef std::map < SWBuf, SWFilter * >FilterMap;
+typedef std::list < SWBuf >StringList;
 
 /** SWMgr is the main class of the Sword library.
 *
@@ -64,7 +63,7 @@ typedef map < string, SWFilter * >FilterMap;
 *
 * To get the SWModule objects of the instalelled modules use @ref Modules for this.
 * @see AddRawFilters(), AddRenderFilters(), AddStripFilters()
-* @version $Id: swmgr.h,v 1.45 2002/08/08 21:35:05 scribe Exp $
+* @version $Id: swmgr.h,v 1.55 2003/07/05 04:58:42 scribe Exp $
 */
 class SWDLLEXPORT SWMgr {
 
@@ -77,16 +76,17 @@ protected:
 	SWConfig *mysysconfig;
 	SWConfig *homeConfig;
 	void CreateMods();
-	SWModule *CreateMod(string name, string driver, ConfigEntMap & section);
+	SWModule *CreateMod(const char *name, const char *driver, ConfigEntMap & section);
 	void DeleteMods();
 	char configType;		// 0 = file; 1 = directory
 	FilterMap optionFilters;
 	FilterMap cipherFilters;
 	SWFilter *gbfplain;
 	SWFilter *thmlplain;
+	SWFilter *osisplain;
 	SWFilter *transliterator;
 	FilterList cleanupFilters;
-	OptionsList options;
+	StringList options;
 	virtual void init(); // use to initialize before loading modules
 	virtual char AddModToConfig(int conffd, const char *fname);
 	virtual void loadConfigDir(const char *ipath);
@@ -96,7 +96,7 @@ protected:
 	virtual void AddLocalOptions(SWModule * module, ConfigEntMap & section,
 	ConfigEntMap::iterator start,
 	ConfigEntMap::iterator end);
-	list<string> augPaths;
+	StringList augPaths;
 
 	/**
 	* Adds the encoding filters which are defined in "section" to the SWModule object "module".
@@ -137,7 +137,7 @@ public:
 	/**
 	*
 	*/
-	static void findConfig(char *configType, char **prefixPath, char **configPath, list<string> *augPaths = 0);
+	static void findConfig(char *configType, char **prefixPath, char **configPath, StringList *augPaths = 0);
 	/** The global config object.
 	* This is the global config object. It contains all items of all modules,
 	* so lookups of entries should use this config object.
@@ -152,7 +152,7 @@ public:
 	*/
 	SWConfig *sysconfig;
 	/** The map of available modules.
-	* This map contains thew list of available modules in Sword.
+	* This map contains the list of available modules in Sword.
 	* Here's an example how to got through the map and how toc ehck for the module type.
 	*
 	*@code
@@ -174,6 +174,7 @@ public:
 	* @endcode
 	*/
 	ModMap Modules;
+	SWModule *getModule(const char *modName) { ModMap::iterator it = Modules.find(modName); return ((it != Modules.end()) ? it->second : 0); }
 	/** The path to your Sword directory
 	*
 	*/
@@ -198,6 +199,7 @@ public:
 	SWMgr(SWFilterMgr *filterMgr);
 	/**
 	*
+	* @param iConfigPath Path to config files.
 	* @param autoload If this bool is true the constructor starts loading the
 	* installed modules. If you reimplemented SWMgr you can set autoload=false
 	* to load the modules with your own reimplemented function.
@@ -230,7 +232,7 @@ public:
 	*/
 	virtual void setGlobalOption(const char *option, const char *value);
 	/** Gives the value of the given option
-	* @param The option, which should be used to return the value of it
+	* @param option The option, which should be used to return the value of it
 	* @return The value of the given option
 	*/
 	virtual const char *getGlobalOption(const char *option);
@@ -243,11 +245,11 @@ public:
 	/** A list of all availble options with the currently set  values
 	* @return This function returns a list of global options.
 	*/
-	virtual OptionsList getGlobalOptions();
+	virtual StringList getGlobalOptions();
 	/**
 	*
 	*/
-	virtual OptionsList getGlobalOptionValues(const char *option);
+	virtual StringList getGlobalOptionValues(const char *option);
 	/**
 	* Sets the cipher key for the given module. This function updates the key
 	* at runtime, but it does not write to the config file.
@@ -287,8 +289,10 @@ public:
 	* @endcode
 	*
 	* @param modName For this module we change the unlockKey
-	* @paran key This is the new unlck key we use for te module.
+	* @param key This is the new unlck key we use for te module.
 	*/
 	virtual signed char setCipherKey(const char *modName, const char *key);
 };
+
+SWORD_NAMESPACE_END
 #endif
