@@ -8,8 +8,8 @@
 #endif
 
 #include <defs.h>
-#include <string.h>
 
+SWORD_NAMESPACE_START
 #define SWDYNAMIC_CAST(className, object) (className *)((object)?((object->getClass()->isAssignableFrom(#className))?object:0):0)
 
 /**
@@ -51,4 +51,5 @@ public:
 	}
 };
 
+SWORD_NAMESPACE_END
 #endif
