@@ -1,6 +1,6 @@
-/*
+/******************************************************************************
  *
- * $Id:
+ * $Id: thmlfootnotes.h,v 1.5 2003/07/05 04:58:42 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -21,38 +21,18 @@
 #ifndef THMLFOOTNOTES_H
 #define THMLFOOTNOTES_H
 
-#include <swfilter.h>
+#include <swoptfilter.h>
 
-#include <defs.h>
+SWORD_NAMESPACE_START
 
 /** This Filter shows/hides footnotes in a ThML text
-  */
-class SWDLLEXPORT ThMLFootnotes:public SWFilter
-{
-  bool option;
-  static const char on[];
-  static const char off[];
-  static const char optName[];
-  static const char optTip[];
-  OptionsList options;
+ */
+class SWDLLEXPORT ThMLFootnotes : public SWOptionFilter {
 public:
-  ThMLFootnotes ();
-  virtual ~ ThMLFootnotes ();
-  virtual char ProcessText (char *text, int maxlen, const SWKey * key, const SWModule * = 0);
-  virtual const char *getOptionName ()
-  {
-    return optName;
-  }
-  virtual const char *getOptionTip ()
-  {
-    return optTip;
-  }
-  virtual void setOptionValue (const char *ival);
-  virtual const char *getOptionValue ();
-  virtual OptionsList getOptionValues ()
-  {
-    return options;
-  }
+	ThMLFootnotes();
+	virtual ~ThMLFootnotes();
+	virtual char processText(SWBuf &text, const SWKey *key = 0, const SWModule *module = 0);
 };
 
+SWORD_NAMESPACE_END
 #endif
