@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: thmlhtmlhref.h,v 1.7 2003/08/12 05:36:30 scribe Exp $
+ * $Id: thmlhtmlhref.h,v 1.10 2003/12/22 04:28:09 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -22,6 +22,7 @@
 #define _THMLHTMLHREF_H
 
 #include <swbasicfilter.h>
+#include <utilxml.h>
 
 SWORD_NAMESPACE_START
 
@@ -31,9 +32,12 @@ class SWDLLEXPORT ThMLHTMLHREF : public SWBasicFilter {
 protected:
 	class MyUserData : public BasicFilterUserData {
 	public:
-		MyUserData(const SWModule *module, const SWKey *key) : BasicFilterUserData(module, key) {}
-		bool inscriptRef;
+		MyUserData(const SWModule *module, const SWKey *key);//: BasicFilterUserData(module, key) {}
+		SWBuf inscriptRef;
 		bool SecHead;
+		bool BiblicalText;
+		SWBuf version;
+		XMLTag startTag;
 	};
 	virtual BasicFilterUserData *createUserData(const SWModule *module, const SWKey *key) {
 		return new MyUserData(module, key);
