@@ -1,6 +1,6 @@
-/*
+/******************************************************************************
  *
- * thmlplain.h
+ * $Id: thmlplain.h,v 1.7 2003/07/26 23:10:55 chrislit Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -23,15 +23,16 @@
 
 #include <swfilter.h>
 
-#include <defs.h>
+SWORD_NAMESPACE_START
 
-  /** this filter converts ThML text to plain text
-  */
-class SWDLLEXPORT ThMLPlain:public SWFilter
-{
+/** this filter converts ThML text to plain text
+ */
+class SWDLLEXPORT ThMLPlain : public SWFilter {
+protected:
+	virtual char processText(SWBuf &text, const SWKey *key = 0, const SWModule *module = 0);
 public:
-  ThMLPlain ();
-  virtual char ProcessText (char *text, int maxlen = -1);
+	ThMLPlain();
 };
 
+SWORD_NAMESPACE_END
 #endif
