@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: thmlrtf.h,v 1.11 2003/08/12 05:36:30 scribe Exp $
+ * $Id: thmlrtf.h,v 1.13 2003/12/22 06:30:44 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -22,6 +22,7 @@
 #define THMLRTF_H
 
 #include <swbasicfilter.h>
+#include <utilxml.h>
 
 SWORD_NAMESPACE_START
 
@@ -31,8 +32,11 @@ class SWDLLEXPORT ThMLRTF : public SWBasicFilter {
 protected:
 	class MyUserData : public BasicFilterUserData {
 	public:
-		MyUserData(const SWModule *module, const SWKey *key) : BasicFilterUserData(module, key) {}
-		bool sechead;
+		MyUserData(const SWModule *module, const SWKey *key);
+		bool SecHead;
+		SWBuf version;
+		bool BiblicalText;
+		XMLTag startTag;
 	};
 	virtual BasicFilterUserData *createUserData(const SWModule *module, const SWKey *key) {
 		return new MyUserData(module, key);
