@@ -1,7 +1,7 @@
 // Include only if your UNIX compiler does not include stricmp but does include strcasecmp
 /*
  *
- * $Id: unixstr.h,v 1.2 2001/02/09 15:38:51 jansorg Exp $
+ * $Id: unixstr.h,v 1.4 2003/06/27 01:41:07 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -21,8 +21,10 @@
 
 #ifndef UNIXSTR_H
 #define UNIXSTR_H
-#include <string.h>
+#include <defs.h>
 
+SWORD_NAMESPACE_START
 int stricmp (const char *s1, const char *s2);
+SWORD_NAMESPACE_END
 
 #endif
