@@ -1,7 +1,7 @@
 /******************************************************************************
  *	versekey.h - code for class 'versekey'- a standard Biblical verse key
  *
- * $Id: versekey.h,v 1.27 2002/08/27 22:52:36 scribe Exp $
+ * $Id: versekey.h,v 1.30 2003/08/13 05:27:02 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -30,6 +30,8 @@
 
 #include <defs.h>
 
+SWORD_NAMESPACE_START
+
 #define POS_MAXVERSE ((char)3)
 #define POS_MAXCHAPTER ((char)4)
 #define POS_MAXBOOK ((char)5)
@@ -69,24 +71,20 @@ class SWLocale;
  * Class VerseKey
  * The SWKey implementation used for verse based modules like Bibles or commentaries.
  */
-class SWDLLEXPORT VerseKey:public SWKey
-{
-	class LocaleCache
-	{
+class SWDLLEXPORT VerseKey:public SWKey {
+	class LocaleCache {
 	public:
 		char *name;
 		unsigned int abbrevsCnt;
 		SWLocale *locale;
-			LocaleCache()
-		{
+			LocaleCache() {
 			name = 0;
 			abbrevsCnt = 0;
 			locale = 0;
 		}
-		 virtual ~LocaleCache()
-		{
+		 virtual ~LocaleCache() {
 			if (name)
-	delete[]name;
+			delete[]name;
 		}
 	};
 
@@ -162,7 +160,7 @@ public:
 	* VerseKey Constructor - initializes Instance of VerseKey
 	*
 	* @param ikey text key (will take various forms of 'BOOK CH:VS'.
-	* See @ref #parse for more detailed information)
+	* See parse() for more detailed information)
 	*/
 	VerseKey(const char *ikey = 0);
 	
@@ -170,13 +168,13 @@ public:
 	* VerseKey Constructor - initializes instance of VerseKey
 	*
 	* @param ikey base key (will take various forms of 'BOOK CH:VS'.
-	*	See @ref #parse for more detailed information)
+	*	See parse() for more detailed information)
 	*/	
 	VerseKey(const SWKey * ikey);
 	
 	/** VerseKey Constructor - initializes instance of VerseKey
-	* with boundariess - see also @ref #LowerBound
-	* and @ref #UpperBound
+	* with boundariess - see also LowerBound()
+	* and UpperBound()
 	* @param min the lower boundary of the new	VerseKey
 	* @param max the upper boundary of the new	VerseKey
 	*/	
@@ -204,7 +202,7 @@ public:
 	
 	/** sets the upper boundary for this	VerseKey
 	* and returns the new boundary
-	* @param lb the new upper boundary for this	VerseKey
+	* @param ub the new upper boundary for this	VerseKey
 	* @return the upper boundary the key was set to
 	*/
 	VerseKey & UpperBound(const char *ub);
@@ -242,24 +240,24 @@ public:
 	
 	/** Positions this key
 	*
-	* @param p position
+	* @param newpos Position to set to.
 	* @return *this
 	*/
-	virtual void setPosition(SW_POSITION);
+	virtual void setPosition(SW_POSITION newpos);
 	
 	/** Decrements key a number of verses
 	*
-	* @param decrement Number of verses to jump backward
+	* @param steps Number of verses to jump backward
 	* @return *this
 	*/
-	virtual void decrement(int step);
+	virtual void decrement(int steps);
 	
 	/** Increments key a number of verses
 	*
-	* @param increment Number of verses to jump forward
+	* @param steps Number of verses to jump forward
 	* @return *this
 	*/
-	virtual void increment(int step);
+	virtual void increment(int steps);
 	virtual char Traversable() { return 1; }
 
 	virtual const char *getBookName() const;
@@ -404,5 +402,5 @@ public:
 	virtual SWKey & operator = (const VerseKey & ikey) { copyFrom(ikey); return *this; }
 };
 
-
+SWORD_NAMESPACE_END
 #endif
