@@ -4,7 +4,7 @@
  *			and provides lookup and parsing functions based on
  *			class StrKey
  *
- * $Id: zstr.h,v 1.5 2002/09/25 21:22:03 scribe Exp $
+ * $Id: zstr.h,v 1.8 2003/08/12 05:36:30 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -26,9 +26,11 @@
 #define ZSTR_H
 
 #include <filemgr.h>
-
+#include <swbuf.h>
 #include <defs.h>
 
+SWORD_NAMESPACE_START
+
 class SWCompress;
 class EntriesBlock;
 
@@ -54,7 +56,7 @@ protected:
 
 	void getCompressedText(long block, long entry, char **buf);
 	void flushCache();
-	void prepText(char *buf);
+	void prepText(SWBuf &buf);
 	void getKeyFromDatOffset(long ioffset, char **buf);
 	void getKeyFromIdxOffset(long ioffset, char **buf);
 
@@ -66,8 +68,9 @@ public:
 	void getText(long index, char **idxbuf, char **buf);
 	void setText(const char *ikey, const char *buf, long len = -1);
 	void linkEntry(const char *destkey, const char *srckey);
-	virtual void rawZFilter(char *buf, long size, char direction = 0) {}
+	virtual void rawZFilter(SWBuf &buf, char direction = 0) {}
 	static signed char createModule (const char *path);
 };
 
+SWORD_NAMESPACE_END
 #endif
