@@ -4,7 +4,6 @@
 
 #include <swmacs.h>
 #include <utilfuns.h>
-#include <string.h>
 #include <stdio.h>
 #include <fcntl.h>
 #include <stdlib.h>
@@ -387,10 +386,13 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 	char comma = 0;
 	char dash = 0;
 	const char *orig = buf;
+	int q;
 	ListKey tmpListKey;
 	ListKey internalListKey;
 	SWKey tmpDefaultKey = defaultKey;
 	char lastPartial = 0;
+	bool inTerm = true;
+	int notAllDigits;
 
 	curkey.AutoNormalize(0);
 	tmpListKey << tmpDefaultKey;
@@ -406,6 +408,21 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 			*number = 0;
 			break;
 
+		case ' ':
+			inTerm = true;
+			while (true) {
+				if ((!*number) || (chap < 0))
+					break;
+				for (q = 1; ((buf[q]) && (buf[q] != ' ')); q++);
+				if (buf[q] == ':')
+					break;
+				inTerm = false;
+				break;
+			}
+			if (inTerm) {
+				book[tobook++] = ' ';
+				break;
+			}
 		case '-': 
 		case ',': // on number new verse
 		case ';': // on number new chapter
@@ -437,27 +454,29 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 					break;
 				}
 
-                    for (loop = strlen(book) - 1; loop+1; loop--) {
-                         if (book[loop] == ' ') {
+                                for (loop = strlen(book) - 1; loop+1; loop--) {
+					if (book[loop] == ' ') {
 						if (isroman(&book[loop+1])) {
-                                   if (verse == -1) {
-                                        verse = chap;
+							if (verse == -1) {
+								verse = chap;
 								chap = from_rom(&book[loop+1]);
 								book[loop] = 0;
-							}
-						}
-						break;
-					}
-				}
+					       	        }
+                                                }
+	        				break;
+                                        }
+                                }
 
-				if ((!stricmp(book, "V")) || (!stricmp(book, "VER"))) {	// Verse abbrev
-                         if (verse == -1) {
-                              verse = chap;
-						chap = VerseKey(tmpListKey).Chapter();
-                              *book = 0;
-                         }
-				}
-				
+                                if ((!stricmp(book, "V")) || (!stricmp(book, "VER"))) {	// Verse abbrev
+                                        if (verse == -1) {
+                                                verse = chap;
+		                		chap = VerseKey(tmpListKey).Chapter();
+                                                *book = 0;
+                                        }
+                                }
+                                if ((!stricmp(book, "ch")) || (!stricmp(book, "chap"))) {	// Verse abbrev
+					strcpy(book, VerseKey(tmpListKey).getBookName());
+                                }
 				bookno = getBookAbbrev(book);
 			}
 			if (((bookno > -1) || (!*book)) && ((*book) || (chap >= 0) || (verse >= 0))) {
@@ -550,11 +569,26 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 			break;
 		case 10:	// ignore these
 		case 13: 
+		case '[': 
+		case ']': 
+		case '(': 
+		case ')': 
 			break;
 		case '.':
 			if (buf > orig)			// ignore (break) if preceeding char is not a digit
-				if (!isdigit(*(buf-1)))
+				for (notAllDigits = tobook; notAllDigits; notAllDigits--) {
+					if ((!isdigit(book[notAllDigits-1])) && (!strchr(" .", book[notAllDigits-1])))
+						break;
+				}
+				if (!notAllDigits)
 					break;
+
+			number[tonumber] = 0;
+			tonumber = 0;
+			if (*number)
+				chap = atoi(number);
+			*number = 0;
+			break;
 			
 		default:
 			if (isdigit(*buf)) {
@@ -625,6 +659,9 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 			}
 		}
 			
+		if ((!stricmp(book, "ch")) || (!stricmp(book, "chap"))) {	// Verse abbrev
+			strcpy(book, VerseKey(tmpListKey).getBookName());
+		}
 		bookno = getBookAbbrev(book);
 	}
 	if (((bookno > -1) || (!*book)) && ((*book) || (chap >= 0) || (verse >= 0))) {
