@@ -2,7 +2,7 @@
  *  localemgr.cpp - implementation of class LocaleMgr used to interact with
  *				registered locales for a sword installation
  *
- * $Id: localemgr.cpp,v 1.14 2002/10/01 22:04:59 dglassey Exp $
+ * $Id: localemgr.cpp,v 1.16 2003/07/05 04:58:42 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -41,14 +41,16 @@
 
 SWORD_NAMESPACE_START
 
+
 LocaleMgr LocaleMgr::systemLocaleMgr;
 
 
 LocaleMgr::LocaleMgr(const char *iConfigPath) {
+	locales = new LocaleMap();
 	char *prefixPath = 0;
 	char *configPath = 0;
 	char configType = 0;
-	std::string path;
+	SWBuf path;
 	
 	defaultLocaleName = 0;
 	
@@ -98,13 +100,14 @@ LocaleMgr::~LocaleMgr() {
 	if (defaultLocaleName)
 		delete [] defaultLocaleName;
      deleteLocales();
+	delete locales;
 }
 
 
 void LocaleMgr::loadConfigDir(const char *ipath) {
 	DIR *dir;
 	struct dirent *ent;
-	std::string newmodfile;
+	SWBuf newmodfile;
 	LocaleMap::iterator it;
  
 	if ((dir = opendir(ipath))) {
@@ -117,12 +120,12 @@ void LocaleMgr::loadConfigDir(const char *ipath) {
 				newmodfile += ent->d_name;
 				SWLocale *locale = new SWLocale(newmodfile.c_str());
 				if (locale->getName()) {
-					it = locales.find(locale->getName());
-					if (it != locales.end()) {
+					it = locales->find(locale->getName());
+					if (it != locales->end()) {
 						*((*it).second) += *locale;
 						delete locale;
 					}
-					else locales.insert(LocaleMap::value_type(locale->getName(), locale));
+					else locales->insert(LocaleMap::value_type(locale->getName(), locale));
 				}
                     else	delete locale;
 			}
@@ -136,27 +139,27 @@ void LocaleMgr::deleteLocales() {
 
 	LocaleMap::iterator it;
 
-	for (it = locales.begin(); it != locales.end(); it++)
+	for (it = locales->begin(); it != locales->end(); it++)
 		delete (*it).second;
 
-	locales.erase(locales.begin(), locales.end());
+	locales->erase(locales->begin(), locales->end());
 }
 
 
 SWLocale *LocaleMgr::getLocale(const char *name) {
 	LocaleMap::iterator it;
 
-	it = locales.find(name);
-	if (it != locales.end())
+	it = locales->find(name);
+	if (it != locales->end())
 		return (*it).second;
 
 	return 0;
 }
 
 
-std::list <std::string> LocaleMgr::getAvailableLocales() {
-	std::list <std::string> retVal;
-	for (LocaleMap::iterator it = locales.begin(); it != locales.end(); it++) 
+std::list <SWBuf> LocaleMgr::getAvailableLocales() {
+	std::list <SWBuf> retVal;
+	for (LocaleMap::iterator it = locales->begin(); it != locales->end(); it++) 
 		retVal.push_back((*it).second->getName());
 
 	return retVal;
