@@ -36,6 +36,7 @@
 #include <osishtmlhref.h>
 #include <gbfwebif.h>
 #include <thmlwebif.h>
+#include <osiswebif.h>
 
 #include <markupfiltmgr.h>
 
@@ -222,7 +223,7 @@ void MarkupFilterMgr::CreateFilters(char markup) {
                         fromplain = new PLAINHTML();
                         fromthml = new ThMLHTMLHREF();
                         fromgbf = new GBFHTMLHREF();
-                        fromosis = new OSISHTMLHref();
+                        fromosis = new OSISHTMLHREF();
                         break;
                 case FMT_RTF:
                         fromplain = NULL;
@@ -240,7 +241,7 @@ void MarkupFilterMgr::CreateFilters(char markup) {
                         fromplain = NULL;
                         fromthml = new ThMLWEBIF();
                         fromgbf = new GBFWEBIF();
-                        fromosis = NULL;
+                        fromosis = new OSISWEBIF();
                         break;
                 }
 
