@@ -2,6 +2,8 @@
 #include <stdlib.h>
 #include <string.h>
 
+SWORD_NAMESPACE_START
+
 const int EntriesBlock::METAHEADERSIZE = 4;
 	// count(4);
 const int EntriesBlock::METAENTRYSIZE = 8;
@@ -164,3 +166,4 @@ void EntriesBlock::removeEntry(int entryIndex) {
 }
 
 
+SWORD_NAMESPACE_END
