@@ -16,7 +16,6 @@
 #include <unistd.h>
 #endif
 
-#include <string.h>
 #include <stdlib.h>
 #include <utilfuns.h>
 #include <rawstr.h>
@@ -96,7 +95,7 @@ RawStr::~RawStr()
  *		buf		- address of pointer to allocate for storage of string
  */
 
-void RawStr::getidxbufdat(long ioffset, char **buf)
+void RawStr::getIDXBufDat(long ioffset, char **buf)
 {
 	int size;
 	char ch;
@@ -112,7 +111,7 @@ void RawStr::getidxbufdat(long ioffset, char **buf)
 			read(datfd->getFd(), *buf, size);
 		}
 		(*buf)[size] = 0;
-		toupperstr_utf8(*buf);
+		toupperstr_utf8(*buf, size*2);
 	}
 	else {
 		*buf = (*buf) ? (char *)realloc(*buf, 1) : (char *)malloc(1);
@@ -130,7 +129,7 @@ void RawStr::getidxbufdat(long ioffset, char **buf)
  *		buf		- address of pointer to allocate for storage of string
  */
 
-void RawStr::getidxbuf(long ioffset, char **buf)
+void RawStr::getIDXBuf(long ioffset, char **buf)
 {
 	char *trybuf, *targetbuf;
 	long offset;
@@ -141,8 +140,7 @@ void RawStr::getidxbuf(long ioffset, char **buf)
 
 		offset = swordtoarch32(offset);
 
-		getidxbufdat(offset, buf);
-		toupperstr_utf8(*buf);
+		getIDXBufDat(offset, buf);
 	}
 }
 
@@ -159,9 +157,9 @@ void RawStr::getidxbuf(long ioffset, char **buf)
  * RET: error status -1 general error; -2 new file
  */
 
-signed char RawStr::findoffset(const char *ikey, long *start, unsigned short *size, long away, long *idxoff)
+signed char RawStr::findOffset(const char *ikey, long *start, unsigned short *size, long away, long *idxoff)
 {
-	char *trybuf, *targetbuf, *key, quitflag = 0;
+	char *trybuf, *targetbuf, *key = 0, quitflag = 0;
 	signed char retval = -1;
 	long headoff, tailoff, tryoff = 0, maxoff = 0;
 
@@ -171,16 +169,15 @@ signed char RawStr::findoffset(const char *ikey, long *start, unsigned short *si
 		if (*ikey) {
 			headoff = 0;
 
-			key = new char [ (strlen(ikey)*2) + 10 ]; // just in case toupper needs a few extra
-			strcpy(key, ikey);
-			toupperstr_utf8(key);
+			stdstr(&key, ikey, 3);
+			toupperstr_utf8(key, strlen(key)*3);
 
 			trybuf = 0;
 
 			while (headoff < tailoff) {
 				tryoff = (lastoff == -1) ? headoff + ((((tailoff / 6) - (headoff / 6))) / 2) * 6 : lastoff; 
 				lastoff = -1;
-				getidxbuf(tryoff, &trybuf);
+				getIDXBuf(tryoff, &trybuf);
 
 				if (!*trybuf && tryoff) {		// In case of extra entry at end of idx (not first entry)
 					tryoff += (tryoff > (maxoff / 2))?-6:6;
@@ -272,11 +269,12 @@ signed char RawStr::findoffset(const char *ikey, long *start, unsigned short *si
  *				text.
  */
 
-void RawStr::preptext(char *buf) {
-	char *to, *from, space = 0, cr = 0, realdata = 0, nlcnt = 0;
-
-	for (to = from = buf; *from; from++) {
-		switch (*from) {
+void RawStr::prepText(SWBuf &buf) {
+	unsigned int to, from; 
+	char space = 0, cr = 0, realdata = 0, nlcnt = 0;
+	char *rawBuf = buf.getRawData();
+	for (to = from = 0; rawBuf[from]; from++) {
+		switch (rawBuf[from]) {
 		case 10:
 			if (!realdata)
 				continue;
@@ -285,14 +283,16 @@ void RawStr::preptext(char *buf) {
 			nlcnt++;
 			if (nlcnt > 1) {
 //				*to++ = nl;
-				*to++ = nl;
+				rawBuf[to++] = 10;
+//				*to++ = nl[1];
 //				nlcnt = 0;
 			}
 			continue;
 		case 13:
 			if (!realdata)
 				continue;
-			*to++ = nl;
+//			*to++ = nl[0];
+			rawBuf[to++] = 10;
 			space = 0;
 			cr = 1;
 			continue;
@@ -301,20 +301,20 @@ void RawStr::preptext(char *buf) {
 		nlcnt = 0;
 		if (space) {
 			space = 0;
-			if (*from != ' ') {
-				*to++ = ' ';
+			if (rawBuf[from] != ' ') {
+				rawBuf[to++] = ' ';
 				from--;
 				continue;
 			}
 		}
-		*to++ = *from;
+		rawBuf[to++] = rawBuf[from];
 	}
-	*to = 0;
+	buf.setSize(to);
 
-	while (to > (buf+1)) {			// remove trailing excess
+	while (to > 1) {			// remove trailing excess
 		to--;
-		if ((*to == 10) || (*to == ' '))
-			*to = 0;
+		if ((rawBuf[to] == 10) || (rawBuf[to] == ' '))
+			buf.setSize(to);
 		else break;
 	}
 }
@@ -330,42 +330,41 @@ void RawStr::preptext(char *buf) {
  *
  */
 
-void RawStr::readtext(long istart, unsigned short *isize, char **idxbuf, char **buf)
+void RawStr::readText(long istart, unsigned short *isize, char **idxbuf, SWBuf &buf)
 {
-	char *ch;
+	unsigned int ch;
 	char *idxbuflocal = 0;
-	getidxbufdat(istart, &idxbuflocal);
+	getIDXBufDat(istart, &idxbuflocal);
 	long start = istart;
 
 	do {
 		if (*idxbuf)
 			delete [] *idxbuf;
-		if (*buf)
-			delete [] *buf;
-		*buf    = new char [ ++(*isize) * FILTERPAD ];
-		*idxbuf = new char [ (*isize) * FILTERPAD ];
+		buf = "";
+		buf.setFillByte(0);
+		buf.setSize(++(*isize));
+
+		*idxbuf = new char [ (*isize) ];
 
-		memset(*buf, 0, *isize);
 		lseek(datfd->getFd(), start, SEEK_SET);
-		read(datfd->getFd(), *buf, (int)((*isize) - 1));
+		read(datfd->getFd(), buf.getRawData(), (int)((*isize) - 1));
 
-		for (ch = *buf; *ch; ch++) {		// skip over index string
-			if (*ch == 10) {
+		for (ch = 0; buf[ch]; ch++) {		// skip over index string
+			if (buf[ch] == 10) {
 				ch++;
 				break;
 			}
 		}
-		memmove(*buf, ch, *isize - (unsigned long)(ch-*buf));
-
+		buf = SWBuf(buf.c_str()+ch);
 		// resolve link
-		if (!strncmp(*buf, "@LINK", 5)) {
-			for (ch = *buf; *ch; ch++) {		// null before nl
-				if (*ch == 10) {
-					*ch = 0;
+		if (!strncmp(buf.c_str(), "@LINK", 5)) {
+			for (ch = 0; buf[ch]; ch++) {		// null before nl
+				if (buf[ch] == 10) {
+					buf[ch] = 0;
 					break;
 				}
 			}
-			findoffset(*buf + 6, &start, isize);
+			findOffset(buf.c_str() + 6, &start, isize);
 		}
 		else break;
 	}
@@ -389,7 +388,7 @@ void RawStr::readtext(long istart, unsigned short *isize, char **idxbuf, char **
  *      len     - length of buffer (0 - null terminated)
  */
 
-void RawStr::settext(const char *ikey, const char *buf, long len)
+void RawStr::doSetText(const char *ikey, const char *buf, long len)
 {
 
 	long start, outstart;
@@ -406,13 +405,13 @@ void RawStr::settext(const char *ikey, const char *buf, long len)
 	char *outbuf = 0;
 	char *ch = 0;
 
-	char errorStatus = findoffset(ikey, &start, &size, 0, &idxoff);
-	stdstr(&key, ikey);
-	toupperstr_utf8(key);
+	char errorStatus = findOffset(ikey, &start, &size, 0, &idxoff);
+	stdstr(&key, ikey, 2);
+	toupperstr_utf8(key, strlen(key)*2);
 
 	len = (len < 0) ? strlen(buf) : len;
 
-	getidxbufdat(start, &dbKey);
+	getIDXBufDat(start, &dbKey);
 
 	if (strcmp(key, dbKey) < 0) {
 	}
@@ -444,7 +443,7 @@ void RawStr::settext(const char *ikey, const char *buf, long len)
 						break;
 					}
 				}
-				findoffset(tmpbuf + 6, &start, &size, 0, &idxoff);
+				findOffset(tmpbuf + 6, &start, &size, 0, &idxoff);
 			}
 			else break;
 		}
@@ -510,10 +509,10 @@ void RawStr::settext(const char *ikey, const char *buf, long len)
  *	srcidxoff		- source offset into .vss
  */
 
-void RawStr::linkentry(const char *destkey, const char *srckey) {
+void RawStr::doLinkEntry(const char *destkey, const char *srckey) {
 	char *text = new char [ strlen(destkey) + 7 ];
 	sprintf(text, "@LINK %s", destkey);
-	settext(srckey, text);
+	doSetText(srckey, text);
 	delete [] text;
 }
 
