@@ -15,7 +15,6 @@
 #include <unistd.h>
 #endif
 
-#include <string.h>
 #include <stdlib.h>
 #include <utilfuns.h>
 #include <rawstr4.h>
@@ -95,7 +94,7 @@ RawStr4::~RawStr4()
  *		buf		- address of pointer to allocate for storage of string
  */
 
-void RawStr4::getidxbufdat(long ioffset, char **buf) {
+void RawStr4::getIDXBufDat(long ioffset, char **buf) {
 	int size;
 	char ch;
 	if (datfd > 0) {
@@ -110,7 +109,7 @@ void RawStr4::getidxbufdat(long ioffset, char **buf) {
 			read(datfd->getFd(), *buf, size);
 		}
 		(*buf)[size] = 0;
-		toupperstr_utf8(*buf);
+		toupperstr_utf8(*buf, size*2);
 	}
 	else {
 		*buf = (*buf) ? (char *)realloc(*buf, 1) : (char *)malloc(1);
@@ -128,7 +127,7 @@ void RawStr4::getidxbufdat(long ioffset, char **buf) {
  *		buf		- address of pointer to allocate for storage of string
  */
 
-void RawStr4::getidxbuf(long ioffset, char **buf)
+void RawStr4::getIDXBuf(long ioffset, char **buf)
 {
 	char *trybuf, *targetbuf;
 	long offset;
@@ -139,13 +138,16 @@ void RawStr4::getidxbuf(long ioffset, char **buf)
 
 		offset = swordtoarch32(offset);
 
-		getidxbufdat(offset, buf);
+		getIDXBufDat(offset, buf);
+		
+/* What the heck is this supposed to do??????
 		for (trybuf = targetbuf = *buf; *trybuf; trybuf++, targetbuf++) {
 			*targetbuf = *trybuf;
 		}
 		*targetbuf = 0;
 		trybuf = 0;
 		toupperstr_utf8(targetbuf);
+*/
 	}
 }
 
@@ -162,9 +164,9 @@ void RawStr4::getidxbuf(long ioffset, char **buf)
  * RET: error status -1 general error; -2 new file
  */
 
-signed char RawStr4::findoffset(const char *ikey, long *start, unsigned long *size, long away, long *idxoff)
+signed char RawStr4::findOffset(const char *ikey, long *start, unsigned long *size, long away, long *idxoff)
 {
-	char *trybuf, *targetbuf, *key, quitflag = 0;
+	char *trybuf, *targetbuf, *key = 0, quitflag = 0;
 	signed char retval = -1;
 	long headoff, tailoff, tryoff = 0, maxoff = 0;
 
@@ -174,16 +176,15 @@ signed char RawStr4::findoffset(const char *ikey, long *start, unsigned long *si
 		if (*ikey) {
 			headoff = 0;
 
-			key = new char [ strlen(ikey) + 1 ];
-			strcpy(key, ikey);
-			toupperstr_utf8(key);
+			stdstr(&key, ikey, 3);
+			toupperstr_utf8(key, strlen(key)*3);
 
 			trybuf = 0;
 
 			while (headoff < tailoff) {
 				tryoff = (lastoff == -1) ? headoff + ((((tailoff / 8) - (headoff / 8))) / 2) * 8 : lastoff; 
 				lastoff = -1;
-				getidxbuf(tryoff, &trybuf);
+				getIDXBuf(tryoff, &trybuf);
 
 				if (!*trybuf) {		// In case of extra entry at end of idx
 					tryoff += (tryoff > (maxoff / 2))?-8:8;
@@ -275,12 +276,12 @@ signed char RawStr4::findoffset(const char *ikey, long *start, unsigned long *si
  *				text.
  */
 
-void RawStr4::preptext(char *buf)
-{
-	char *to, *from, space = 0, cr = 0, realdata = 0, nlcnt = 0;
-
-	for (to = from = buf; *from; from++) {
-		switch (*from) {
+void RawStr4::prepText(SWBuf &buf) {
+	unsigned int to, from; 
+	char space = 0, cr = 0, realdata = 0, nlcnt = 0;
+	char *rawBuf = buf.getRawData();
+	for (to = from = 0; rawBuf[from]; from++) {
+		switch (rawBuf[from]) {
 		case 10:
 			if (!realdata)
 				continue;
@@ -289,14 +290,16 @@ void RawStr4::preptext(char *buf)
 			nlcnt++;
 			if (nlcnt > 1) {
 //				*to++ = nl;
-				*to++ = nl;
+				rawBuf[to++] = 10;
+//				*to++ = nl[1];
 //				nlcnt = 0;
 			}
 			continue;
 		case 13:
 			if (!realdata)
 				continue;
-			*to++ = nl;
+//			*to++ = nl[0];
+			rawBuf[to++] = 10;
 			space = 0;
 			cr = 1;
 			continue;
@@ -305,20 +308,20 @@ void RawStr4::preptext(char *buf)
 		nlcnt = 0;
 		if (space) {
 			space = 0;
-			if (*from != ' ') {
-				*to++ = ' ';
+			if (rawBuf[from] != ' ') {
+				rawBuf[to++] = ' ';
 				from--;
 				continue;
 			}
 		}
-		*to++ = *from;
+		rawBuf[to++] = rawBuf[from];
 	}
-	*to = 0;
+	buf.setSize(to);
 
-	while (to > (buf+1)) {			// remove trailing excess
+	while (to > 1) {			// remove trailing excess
 		to--;
-		if ((*to == 10) || (*to == ' '))
-			*to = 0;
+		if ((rawBuf[to] == 10) || (rawBuf[to] == ' '))
+			buf.setSize(to);
 		else break;
 	}
 }
@@ -334,42 +337,41 @@ void RawStr4::preptext(char *buf)
  *
  */
 
-void RawStr4::readtext(long istart, unsigned long *isize, char **idxbuf, char **buf)
+void RawStr4::readText(long istart, unsigned long *isize, char **idxbuf, SWBuf &buf)
 {
-	char *ch;
+	unsigned int ch;
 	char *idxbuflocal = 0;
-	getidxbufdat(istart, &idxbuflocal);
+	getIDXBufDat(istart, &idxbuflocal);
 	long start = istart;
 
 	do {
 		if (*idxbuf)
 			delete [] *idxbuf;
-		if (*buf)
-			delete [] *buf;
-		*buf    = new char [ ++(*isize) * FILTERPAD ];
-		*idxbuf = new char [ (*isize) * FILTERPAD ];
+		*idxbuf = new char [ (*isize) ];
 
-		memset(*buf, 0, *isize);
+		buf = "";
+		buf.setFillByte(0);
+		buf.setSize(*isize);
 		lseek(datfd->getFd(), start, SEEK_SET);
-		read(datfd->getFd(), *buf, (int)((*isize) - 1));
+		read(datfd->getFd(), buf.getRawData(), (int)((*isize) - 1));
 
-		for (ch = *buf; *ch; ch++) {		// skip over index string
-			if (*ch == 10) {
+		for (ch = 0; buf[ch]; ch++) {		// skip over index string
+			if (buf[ch] == 10) {
 				ch++;
 				break;
 			}
 		}
-		memmove(*buf, ch, *isize - (unsigned long)(ch-*buf));
-
+		buf = SWBuf(buf.c_str()+ch);
 		// resolve link
-		if (!strncmp(*buf, "@LINK", 5)) {
-			for (ch = *buf; *ch; ch++) {		// null before nl
-				if (*ch == 10) {
-					*ch = 0;
+		if (!strncmp(buf.c_str(), "@LINK", 5)) {
+			for (ch = 0; buf[ch]; ch++) {		// null before nl
+				if (buf[ch] == 10) {
+					buf[ch] = 0;
 					break;
 				}
 			}
-			findoffset(*buf + 6, &start, isize);
+			findOffset(buf.c_str() + 6, &start, isize);
+
 		}
 		else break;
 	}
@@ -393,7 +395,7 @@ void RawStr4::readtext(long istart, unsigned long *isize, char **idxbuf, char **
  *      len     - length of buffer (0 - null terminated)
  */
 
-void RawStr4::setText(const char *ikey, const char *buf, long len) {
+void RawStr4::doSetText(const char *ikey, const char *buf, long len) {
 
 	long start, outstart;
 	long idxoff;
@@ -409,12 +411,12 @@ void RawStr4::setText(const char *ikey, const char *buf, long len) {
 	char *outbuf = 0;
 	char *ch = 0;
 
-	char errorStatus = findoffset(ikey, &start, &size, 0, &idxoff);
-	stdstr(&key, ikey);
-	toupperstr_utf8(key);
+	char errorStatus = findOffset(ikey, &start, &size, 0, &idxoff);
+	stdstr(&key, ikey, 3);
+	toupperstr_utf8(key, strlen(key)*3);
 
 	len = (len < 0) ? strlen(buf) : len;
-	getidxbufdat(start, &dbKey);
+	getIDXBufDat(start, &dbKey);
 
 	if (strcmp(key, dbKey) < 0) {
 	}
@@ -446,7 +448,7 @@ void RawStr4::setText(const char *ikey, const char *buf, long len) {
 						break;
 					}
 				}
-				findoffset(tmpbuf + 8, &start, &size, 0, &idxoff);
+				findOffset(tmpbuf + 8, &start, &size, 0, &idxoff);
 				++size;
 			}
 			else break;
@@ -513,10 +515,10 @@ void RawStr4::setText(const char *ikey, const char *buf, long len) {
  *	srcidxoff		- source offset into .vss
  */
 
-void RawStr4::linkentry(const char *destkey, const char *srckey) {
+void RawStr4::doLinkEntry(const char *destkey, const char *srckey) {
 	char *text = new char [ strlen(destkey) + 7 ];
 	sprintf(text, "@LINK %s", destkey);
-	setText(srckey, text);
+	doSetText(srckey, text);
 	delete [] text;
 }
 
