@@ -14,7 +14,6 @@
 #include <unistd.h>
 #endif
 
-#include <string.h>
 #include <stdlib.h>
 #include <utilfuns.h>
 #include <zstr.h>
@@ -132,7 +131,7 @@ void zStr::getKeyFromDatOffset(long ioffset, char **buf) {
 			read(datfd->getFd(), *buf, size);
 		}
 		(*buf)[size] = 0;
-		toupperstr_utf8(*buf);
+		toupperstr_utf8(*buf, size*2);
 	}
 	else {
 		*buf = (*buf) ? (char *)realloc(*buf, 1) : (char *)malloc(1);
@@ -184,8 +183,8 @@ signed char zStr::findKeyIndex(const char *ikey, long *idxoff, long away) {
 		tailoff = maxoff = lseek(idxfd->getFd(), 0, SEEK_END) - IDXENTRYSIZE;
 		if (*ikey) {
 			headoff = 0;
-			stdstr(&key, ikey);
-			toupperstr_utf8(key);
+			stdstr(&key, ikey, 3);
+			toupperstr_utf8(key, strlen(key)*3);
 
 			while (headoff < tailoff) {
 				tryoff = (lastoff == -1) ? headoff + (((((tailoff / IDXENTRYSIZE) - (headoff / IDXENTRYSIZE))) / 2) * IDXENTRYSIZE) : lastoff;
@@ -282,11 +281,12 @@ signed char zStr::findKeyIndex(const char *ikey, long *idxoff, long away) {
  *				text.
  */
 
-void zStr::prepText(char *buf) {
-	char *to, *from, space = 0, cr = 0, realdata = 0, nlcnt = 0;
-
-	for (to = from = buf; *from; from++) {
-		switch (*from) {
+void zStr::prepText(SWBuf &buf) {
+	unsigned int to, from; 
+	char space = 0, cr = 0, realdata = 0, nlcnt = 0;
+	char *rawBuf = buf.getRawData();
+	for (to = from = 0; rawBuf[from]; from++) {
+		switch (rawBuf[from]) {
 		case 10:
 			if (!realdata)
 				continue;
@@ -295,14 +295,16 @@ void zStr::prepText(char *buf) {
 			nlcnt++;
 			if (nlcnt > 1) {
 //				*to++ = nl;
-				*to++ = nl;
+				rawBuf[to++] = 10;
+//				*to++ = nl[1];
 //				nlcnt = 0;
 			}
 			continue;
 		case 13:
 			if (!realdata)
 				continue;
-			*to++ = nl;
+//			*to++ = nl[0];
+			rawBuf[to++] = 10;
 			space = 0;
 			cr = 1;
 			continue;
@@ -311,20 +313,20 @@ void zStr::prepText(char *buf) {
 		nlcnt = 0;
 		if (space) {
 			space = 0;
-			if (*from != ' ') {
-				*to++ = ' ';
+			if (rawBuf[from] != ' ') {
+				rawBuf[to++] = ' ';
 				from--;
 				continue;
 			}
 		}
-		*to++ = *from;
+		rawBuf[to++] = rawBuf[from];
 	}
-	*to = 0;
+	buf.setSize(to);
 
-	while (to > (buf+1)) {			// remove trailing excess
+	while (to > 1) {			// remove trailing excess
 		to--;
-		if ((*to == 10) || (*to == ' '))
-			*to = 0;
+		if ((rawBuf[to] == 10) || (rawBuf[to] == ' '))
+			buf.setSize(to);
 		else break;
 	}
 }
@@ -420,19 +422,19 @@ void zStr::getCompressedText(long block, long entry, char **buf) {
 		start = swordtoarch32(start);
 		size = swordtoarch32(size);
 
-		*buf = (*buf) ? (char *)realloc(*buf, size*2 + 1) : (char *)malloc(size*2 + 1);
-
+		SWBuf buf;
+		buf.setSize(size + 5);
 		lseek(zdtfd->getFd(), start, SEEK_SET);
-		read(zdtfd->getFd(), *buf, size);
+		read(zdtfd->getFd(), buf.getRawData(), size);
 
 		flushCache();
 
 		unsigned long len = size;
+		buf.setSize(size);
+		rawZFilter(buf, 0); // 0 = decipher
 
-		rawZFilter(*buf, len, 0); // 0 = decipher
-
-		compressor->zBuf(&len, *buf);
-		char * rawBuf = compressor->Buf(0, &len);
+		compressor->zBuf(&len, buf.getRawData());
+		char *rawBuf = compressor->Buf(0, &len);
 		cacheBlock = new EntriesBlock(rawBuf, len);
 		cacheBlockIndex = block;
 	}
@@ -466,8 +468,8 @@ void zStr::setText(const char *ikey, const char *buf, long len) {
 	char *ch = 0;
 
 	len = (len < 0) ? strlen(buf) : len;
-	stdstr(&key, ikey);
-	toupperstr_utf8(key);
+	stdstr(&key, ikey, 3);
+	toupperstr_utf8(key, strlen(key)*3);
 
 	char notFound = findKeyIndex(ikey, &idxoff, 0);
 	if (!notFound) {
@@ -615,9 +617,11 @@ void zStr::flushCache() {
 			compressor->Buf(rawBuf, &size);
 			compressor->zBuf(&size);
 
-			char *buf = new char [ size * 2 ];
-			memcpy(buf, compressor->zBuf(&size), size); // 1 = encipher
-			rawZFilter(buf, size, 1); // 1 = encipher
+			SWBuf buf;
+			buf.setSize(size + 5);
+			memcpy(buf.getRawData(), compressor->zBuf(&size), size); // 1 = encipher
+			buf.setSize(size);
+			rawZFilter(buf, 1); // 1 = encipher
 
 			long zdxSize = lseek(zdxfd->getFd(), 0, SEEK_END);
 			long zdtSize = lseek(zdtfd->getFd(), 0, SEEK_END);
@@ -656,12 +660,11 @@ void zStr::flushCache() {
 			
 			write(zdxfd->getFd(), &outstart, sizeof(__u32));
 			write(zdxfd->getFd(), &outsize, sizeof(__u32));
-
-			delete cacheBlock;
 		}
+		delete cacheBlock;
+		cacheBlock = 0;
 	}
 	cacheBlockIndex = -1;
-	cacheBlock = 0;
 	cacheDirty = false;
 }
 
