@@ -15,7 +15,11 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <stdlib.h>
 #include <gbfhtmlhref.h>
+#include <swmodule.h>
+#include <utilxml.h>
+#include <versekey.h>
 #include <ctype.h>
 
 SWORD_NAMESPACE_START
@@ -26,7 +30,8 @@ GBFHTMLHREF::GBFHTMLHREF() {
 	
 	setTokenCaseSensitive(true);
 
-	addTokenSubstitute("Rf", ")</small></font>");
+	//addTokenSubstitute("Rf", ")</small></font>");
+	addTokenSubstitute("FA", "<font color=\"#800000\">"); // for ASV footnotes to mark text
 	addTokenSubstitute("Rx", "</a>");
 	addTokenSubstitute("FI", "<i>"); // italics begin
 	addTokenSubstitute("Fi", "</i>");
@@ -65,18 +70,9 @@ bool GBFHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData
 	const char *num;
 	MyUserData *u = (MyUserData *)userData;
 
-	if (!substituteToken(buf, token)) {		
-		// deal with OSIS note tags.  Just hide till OSISRTF		
-		if (!strncmp(token, "note ", 5)) {
-			// let's stop text from going to output
-			u->suspendTextPassThru = true;
-		}
-		
-		else if (!strncmp(token, "/note", 5)) {
-			u->suspendTextPassThru = false;
-		}		
-
-		else if (!strncmp(token, "w", 1)) {
+	if (!substituteToken(buf, token)) {
+		XMLTag tag(token);
+		if (!strncmp(token, "w", 1)) {
 			// OSIS Word (temporary until OSISRTF is done)
 			valto = val;
 			num = strstr(token, "lemma=\"x-Strongs:");
@@ -157,7 +153,7 @@ bool GBFHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData
 			buf += "</a>)</em></small>";
 		}
 
-		else if (!strncmp(token, "RX", 2)) {
+		else if (!strcmp(tag.getName(), "RX")) {
 			buf += "<a href=\"";
 			for (tok = token + 3; *tok; tok++) {
 			  if(*tok != '<' && *tok+1 != 'R' && *tok+2 != 'x') {
@@ -169,20 +165,48 @@ bool GBFHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData
 			}
 			buf += "\">";
 		}
-
+		else if (!strcmp(tag.getName(), "RF")) {
+			SWBuf type = tag.getAttribute("type");
+			SWBuf footnoteNumber = tag.getAttribute("swordFootnote");
+			VerseKey *vkey;
+			// see if we have a VerseKey * or descendant
+			try {
+				vkey = SWDYNAMIC_CAST(VerseKey, u->key);
+			}
+			catch ( ... ) {	}
+			if (vkey) {
+				// leave this special osis type in for crossReference notes types?  Might thml use this some day? Doesn't hurt.
+				//char ch = ((tag.getAttribute("type") && ((!strcmp(tag.getAttribute("type"), "crossReference")) || (!strcmp(tag.getAttribute("type"), "x-cross-ref")))) ? 'x':'n');
+				buf.appendFormatted("<a href=\"noteID=%s.%c.%s\"><small><sup>*%c</sup></small></a> ", vkey->getText(), 'n', footnoteNumber.c_str(), 'n');
+			}
+			u->suspendTextPassThru = true;
+		}
+		else if (!strcmp(tag.getName(), "Rf")) {
+			u->suspendTextPassThru = false;
+		}
+/*
 		else if (!strncmp(token, "RB", 2)) {
 			buf += "<i> ";
 			u->hasFootnotePreTag = true;
 		}
 
+		else if (!strncmp(token, "Rf", 2)) {
+			buf += "&nbsp<a href=\"note=";
+			buf += u->lastTextNode.c_str();
+			buf += "\">";
+			buf += "<small><sup>*n</sup></small></a>&nbsp";
+			// let's let text resume to output again
+			u->suspendTextPassThru = false;
+		}
+		
 		else if (!strncmp(token, "RF", 2)) {
 			if (u->hasFootnotePreTag) {
 				u->hasFootnotePreTag = false;
 				buf += "</i> ";
 			}
-			buf += "<font color=\"#800000\"><small> (";
+			u->suspendTextPassThru = true;
 		}
-
+*/
 		else if (!strncmp(token, "FN", 2)) {
 			buf += "<font face=\"";
 			for (tok = token + 2; *tok; tok++)				
