@@ -1,13 +1,12 @@
 /******************************************************************************
  *
- * gbfstrongs -	SWFilter decendant to hide or show strongs number
+ * gbfstrongs -	SWFilter descendant to hide or show strongs number
  *			in a GBF module.
  */
 
 
 #include <stdlib.h>
 #include <stdio.h>
-#include <string>
 #include <stdarg.h>
 #include <gbfosis.h>
 #include <swmodule.h>
@@ -29,8 +28,8 @@ GBFOSIS::~GBFOSIS() {
 }
 
 
-char GBFOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWModule *module) {
-
+char GBFOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module) { 
+/*
 	char *to, *from, token[2048]; // cheese.  Fix.
 	int tokpos = 0;
 	bool intoken = false;
@@ -47,9 +46,10 @@ char GBFOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWModu
 	char *fromStart;
 	bool newText = false;
 	bool newWord = false;
-	std::string tmp;
+	SWBuf tmp;
 	bool suspendTextPassThru = false;
 	bool keepToken = false;
+	bool handled = false;
 
 	len = strlen(text) + 1;	// shift string to right of buffer
 	if (len < maxlen) {
@@ -82,7 +82,7 @@ char GBFOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWModu
 			keepToken = false;
 			suspendTextPassThru = false;
 			newWord = true;
-
+			handled = false;
 
 			while (wordStart < (text+maxlen)) {
 //				if (strchr(" ,;.?!()'\"", *wordStart))
@@ -101,6 +101,7 @@ char GBFOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWModu
 	//			pushString(buf, "<reference work=\"Bible.KJV\" reference=\"");
 				suspendTextPassThru = true;
 				newText = true;
+				handled = true;
 			}
 			else	if (!strncmp(token, "/scripRef", 9)) {
 				tmp = "";
@@ -108,6 +109,7 @@ char GBFOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWModu
 				pushString(&to, convertToOSIS(tmp.c_str(), key));
 				lastspace = false;
 				suspendTextPassThru = false;
+				handled = true;
 			}
 
 			// Footnote
@@ -116,41 +118,76 @@ char GBFOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWModu
 				pushString(&to, "<note type=\"x-StudyNote\">");
 				newText = true;
 				lastspace = false;
+				handled = true;
 			}
 			else	if (!strcmp(token, "Rf")) {
 				pushString(&to, "</note>");
 				lastspace = false;
+				handled = true;
+			}
+			// hebrew titles
+			if (!strcmp(token, "TH")) {
+				pushString(&to, "<title type=\"psalm\">");
+				newText = true;
+				lastspace = false;
+				handled = true;
+			}
+			else	if (!strcmp(token, "Th")) {
+				pushString(&to, "</title>");
+				lastspace = false;
+				handled = true;
+			}
+			// Italics assume transchange
+			if (!strcmp(token, "FI")) {
+				pushString(&to, "<transChange type=\"added\">");
+				newText = true;
+				lastspace = false;
+				handled = true;
+			}
+			else	if (!strcmp(token, "Fi")) {
+				pushString(&to, "</transChange>");
+				lastspace = false;
+				handled = true;
+			}
+			// Paragraph break.  For now use empty paragraph element
+			if (!strcmp(token, "CM")) {
+				pushString(&to, "<milestone type=\"x-p\" />");
+				newText = true;
+				lastspace = false;
+				handled = true;
 			}
 
 			// Figure
 			else	if (!strncmp(token, "img ", 4)) {
 				const char *src = strstr(token, "src");
 				if (!src)		// assert we have a src attribute
-					return false;
+					continue;
+//					return false;
 
 				pushString(&to, "<figure src=\"");
 				const char *c;
 				for (c = src;((*c) && (*c != '"')); c++);
 
-				/* uncomment for SWORD absolute path logic
-				if (*(c+1) == '/') {
-					pushString(buf, "file:");
-					pushString(buf, module->getConfigEntry("AbsoluteDataPath"));
-					if (*((*buf)-1) == '/')
-						c++;		// skip '/'
-				}
-				end of uncomment for asolute path logic */
+// uncomment for SWORD absolute path logic
+//				if (*(c+1) == '/') {
+//					pushString(buf, "file:");
+//					pushString(buf, module->getConfigEntry("AbsoluteDataPath"));
+//					if (*((*buf)-1) == '/')
+//						c++;		// skip '/'
+//				}
+// end of uncomment for asolute path logic 
 
 				for (c++;((*c) && (*c != '"')); c++)
 					*to++ = *c;
 
 				pushString(&to, "\" />");
 				lastspace = false;
-				return true;
+				handled = true;
 			}
 
 			// Strongs numbers
 			else if (*token == 'W' && (token[1] == 'G' || token[1] == 'H')) {	// Strongs
+				bool divineName = false;
 				if (module->isProcessEntryAttributes()) {
 					valto = val;
 					for (unsigned int i = 1; ((token[i]) && (i < 150)); i++)
@@ -175,15 +212,27 @@ char GBFOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWModu
 						to+=strlen(buf);
 					}
 					else {
-						sprintf(buf, "<w lemma=\"x-Strongs:%s\">", val);
+						if (!strcmp(val, "H03068")) {	//divineName
+							sprintf(buf, "<divineName><w lemma=\"x-Strongs:%s\">", val);
+							divineName = true;
+						}
+						else sprintf(buf, "<w lemma=\"x-Strongs:%s\">", val);
+
 						memmove(wordStart+strlen(buf), wordStart, (to-wordStart)+1);
 						memcpy(wordStart, buf, strlen(buf));
 						to+=strlen(buf);
-						pushString(&to, "</w>");
+
+						if (divineName) {
+							wordStart += 12;
+							pushString(&to, "</w></divineName>");
+						}
+						else	pushString(&to, "</w>");
+
 						module->getEntryAttributes()["Word"][wordstr]["Strongs"] = val;
 						lastspace = false;
 					}
 				}
+				handled = true;
 			}
 
 			// Morphology
@@ -217,9 +266,14 @@ char GBFOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWModu
 					pushString(&to, "</w>");
 					lastspace = false;
 				}
+				handled = true;
 			}
 
-			if (!keepToken) {	// if we don't want strongs
+			if (!keepToken) {	
+				if (!handled) {
+					SWLog::systemlog->LogError("Unprocessed Token: <%s>", token);
+//					exit(-1);
+				}
 				if (from[1] && strchr(" ,;.:?!()'\"", from[1])) {
 					if (lastspace)
 						to--;
@@ -248,7 +302,8 @@ char GBFOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWModu
 			case '\'':
 			case '\"':
 			case '`':
-				quoteStack.handleQuote(fromStart, from, &to);
+//				quoteStack.handleQuote(fromStart, from, &to);
+				*to++ = *from;
 				from++;
 				break;
 			default:
@@ -266,10 +321,6 @@ char GBFOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWModu
 		char ref[254];
 		if (vkey->Verse())
 			sprintf(ref, "\t\t<verse osisID=\"%s\">", vkey->getOSISRef());
-		else if (vkey->Chapter())
-			sprintf(ref, "\t<div type=\"chapter\" osisID=\"%s\">", vkey->getOSISRef());
-		else if (vkey->Book())
-			sprintf(ref, "\t<div type=\"book\" osisID=\"%s\">", vkey->getOSISRef());
 		else *ref = 0;
 		if (*ref) {
 			memmove(text+strlen(ref), text, maxlen-strlen(ref)-1);
@@ -285,15 +336,15 @@ char GBFOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWModu
 				tmp = MAXVERSE;
 				if (*vkey == tmp) {
 					tmp.Verse(0);
-					sprintf(ref, "\t</div>");
-					pushString(&to, ref);
+//					sprintf(ref, "\t</div>");
+//					pushString(&to, ref);
 					tmp = MAXCHAPTER;
 					tmp = MAXVERSE;
 					if (*vkey == tmp) {
 						tmp.Chapter(0);
 						tmp.Verse(0);
-						sprintf(ref, "\t</div>");
-						pushString(&to, ref);
+//						sprintf(ref, "\t</div>");
+//						pushString(&to, ref);
 						if (!quoteStack.empty()) {
 							SWLog::systemlog->LogError("popping unclosed quote at end of book");
 							quoteStack.clear();
@@ -302,30 +353,23 @@ char GBFOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWModu
 				}
 			}
 
-			else if (vkey->Chapter())
-				sprintf(ref, "\t<div type=\"chapter\" osisID=\"%s\">", vkey->getOSISRef());
-			else sprintf(ref, "\t<div type=\"book\" osisID=\"%s\">", vkey->getOSISRef());
+//
+//			else if (vkey->Chapter()) {
+//				sprintf(ref, "\t<div type=\"chapter\" osisID=\"%s\">", vkey->getOSISRef());
+//			}
+//			else sprintf(ref, "\t<div type=\"book\" osisID=\"%s\">", vkey->getOSISRef());
+//
 		}
 	}
 	*to++ = 0;
 	*to = 0;
+*/
 	return 0;
 }
 
 
-void GBFOSIS::pushString(char **buf, const char *format, ...) {
-  va_list argptr;
-
-  va_start(argptr, format);
-  *buf += vsprintf(*buf, format, argptr);
-  va_end(argptr);
-
-//  *buf += strlen(*buf);
-}
-
-
 const char *GBFOSIS::convertToOSIS(const char *inRef, const SWKey *key) {
-	static std::string outRef;
+	static SWBuf outRef;
 
 	outRef = "";
 
@@ -340,7 +384,7 @@ const char *GBFOSIS::convertToOSIS(const char *inRef, const SWKey *key) {
 			memmove(frag, startFrag, ((const char *)element->userData - startFrag) + 1);
 			frag[((const char *)element->userData - startFrag) + 1] = 0;
 			startFrag = (const char *)element->userData + 1;
-			sprintf(buf, "<reference osisRef=\"%s-\"%s\">%s</reference>", element->LowerBound().getOSISRef(), element->UpperBound().getOSISRef(), frag);
+			sprintf(buf, "<reference osisRef=\"%s-%s\">%s</reference>", element->LowerBound().getOSISRef(), element->UpperBound().getOSISRef(), frag);
 		}
 		else {
 			memmove(frag, startFrag, ((const char *)verses.GetElement(i)->userData - startFrag) + 1);
@@ -369,27 +413,27 @@ QuoteStack::~QuoteStack() {
 }
 
 
-void QuoteStack::handleQuote(char *buf, char *quotePos, char **to) {
+void QuoteStack::handleQuote(char *buf, char *quotePos, SWBuf &text) {
 //QuoteInstance(char startChar = '\"', char level = 1, string uniqueID = "", char continueCount = 0) {
 	if (!quotes.empty()) {
 		QuoteInstance last = quotes.top();
 		if (last.startChar == *quotePos) {
-			GBFOSIS::pushString(to, "</quote>");
+			text += "</quote>";
 			quotes.pop();
 		}
 		else {
 			quotes.push(QuoteInstance(*quotePos, last.level+1));
-			quotes.top().pushStartStream(to);
+			quotes.top().pushStartStream(text);
 		}
 	}
 	else {
 		quotes.push(QuoteInstance(*quotePos));
-		quotes.top().pushStartStream(to);
+		quotes.top().pushStartStream(text);
 	}
 }
 
-void QuoteStack::QuoteInstance::pushStartStream(char **to) {
-	GBFOSIS::pushString(to, "<quote level=\"%d\">", level);
+void QuoteStack::QuoteInstance::pushStartStream(SWBuf &text) {
+	text.appendFormatted("<quote level=\"%d\">", level);
 }
 
 SWORD_NAMESPACE_END
