@@ -1,7 +1,7 @@
 /******************************************************************************
  *
- * greeklexattribs -	SWFilter decendant to set entry attributes for greek
- * 	lexicons
+ * greeklexattribs -	SWFilter descendant to set entry attributes for greek
+ * 	                lexicons
  */
 
 
@@ -19,21 +19,21 @@ GreekLexAttribs::GreekLexAttribs() {
 }
 
 
-char GreekLexAttribs::ProcessText(char *text, int maxlen, const SWKey *key, const SWModule *module) {
+char GreekLexAttribs::processText(SWBuf &text, const SWKey *key, const SWModule *module) {
 
 	if (module->isProcessEntryAttributes()) {
-		char *from;
+		const char *from;
 		bool inAV = false;
 		string phrase;
 		string freq;
 		char val[128], *valto;
 		char wordstr[7];
-		char *currentPhrase = 0, *ch = 0;
-		char *currentPhraseEnd = 0;
+		const char *currentPhrase = 0, *ch = 0;
+		const char *currentPhraseEnd = 0;
 		int number = 0;
 
 
-		for (from = text; *from; from++) {
+		for (from = text.c_str(); *from; from++) {
 			if (inAV) {
 				if (currentPhrase == 0) {
 					if (isalpha(*from))
@@ -60,7 +60,7 @@ char GreekLexAttribs::ProcessText(char *text, int maxlen, const SWKey *key, cons
 						}
 
 						phrase = "";
-						phrase.append(currentPhrase, (int)(((currentPhraseEnd)?currentPhraseEnd:from) - currentPhrase)-1);
+						phrase.append(currentPhrase, (int)(((currentPhraseEnd>currentPhrase)?currentPhraseEnd:from) - currentPhrase)-1);
 						currentPhrase = from;
 						while (*from && isdigit(*from)) from++;
 						freq = "";
@@ -72,13 +72,13 @@ char GreekLexAttribs::ProcessText(char *text, int maxlen, const SWKey *key, cons
 								phrase.erase(phrase.find_first_of("("), 1);
 								phrase.erase(phrase.find_first_of(")"), 1);
 								phrase.erase(0,phrase.find_first_not_of("\r\n\v\t ")); phrase.erase(phrase.find_last_not_of("\r\n\v\t ")+1);
-								module->getEntryAttributes()["AVPhrase"][wordstr]["Alt"] = phrase;
+								module->getEntryAttributes()["AVPhrase"][wordstr]["Alt"] = phrase.c_str();
 								phrase = tmp;
 							}
 							phrase.erase(0,phrase.find_first_not_of("\r\n\v\t ")); phrase.erase(phrase.find_last_not_of("\r\n\v\t ")+1);
 							freq.erase(0,freq.find_first_not_of("\r\n\v\t ")); freq.erase(freq.find_last_not_of("\r\n\v\t ")+1);
-							module->getEntryAttributes()["AVPhrase"][wordstr]["Phrase"] = phrase;
-							module->getEntryAttributes()["AVPhrase"][wordstr]["Frequency"] = freq;
+							module->getEntryAttributes()["AVPhrase"][wordstr]["Phrase"] = phrase.c_str();
+							module->getEntryAttributes()["AVPhrase"][wordstr]["Frequency"] = freq.c_str();
 							currentPhrase = 0;
 							currentPhraseEnd = 0;
 						}
