@@ -23,12 +23,12 @@
 SWORD_NAMESPACE_START
 
 
-OSISHTMLHref::MyUserData::MyUserData(const SWModule *module, const SWKey *key) : BasicFilterUserData(module, key) {
+OSISHTMLHREF::MyUserData::MyUserData(const SWModule *module, const SWKey *key) : BasicFilterUserData(module, key) {
 	osisQToTick = ((!module->getConfigEntry("OSISqToTick")) || (strcmp(module->getConfigEntry("OSISqToTick"), "false")));
 }
 
 
-OSISHTMLHref::OSISHTMLHref() {
+OSISHTMLHREF::OSISHTMLHREF() {
 	setTokenStart("<");
 	setTokenEnd(">");
 
@@ -49,7 +49,7 @@ OSISHTMLHref::OSISHTMLHref() {
 }
 
 
-bool OSISHTMLHref::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *userData) {
+bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *userData) {
   // manually process if it wasn't a simple substitution
 	if (!substituteToken(buf, token)) {
 		MyUserData *u = (MyUserData *)userData;
@@ -300,7 +300,7 @@ bool OSISHTMLHref::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 			strcat(filepath, src);
 
 // we do this because BibleCS looks for this EXACT format for an image tag
-			buf+="<figure src=\"";
+			buf+="<image src=\"";
 			buf+=filepath;
 			buf+="\" />";
 /*
