@@ -19,7 +19,6 @@
 #include <swkey.h>
 
 #include <stdlib.h>
-#include <string.h>
 #ifndef __GNUC__
 #else
 #include <unixstr.h>
@@ -27,77 +26,56 @@
 
 SWORD_NAMESPACE_START
 
-const char PLAINFootnotes::on[] = "On";
-const char PLAINFootnotes::off[] = "Off";
-const char PLAINFootnotes::optName[] = "Footnotes";
-const char PLAINFootnotes::optTip[] = "Toggles Footnotes On and Off In Bible Texts If They Exist";
+const char oName[] = "Footnotes";
+const char oTip[] = "Toggles Footnotes On and Off In Bible Texts If They Exist";
 
-PLAINFootnotes::PLAINFootnotes(){
-	option = false;
-	options.push_back(on);
-	options.push_back(off);
+const SWBuf choices[3] = {"On", "Off", ""};
+const StringList oValues(&choices[0], &choices[2]);
+
+PLAINFootnotes::PLAINFootnotes() : SWOptionFilter(oName, oTip, &oValues) {
+	setOptionValue("Off");
 }
 
 PLAINFootnotes::~PLAINFootnotes(){
 }
 
 
-void PLAINFootnotes::setOptionValue(const char *ival)
-{
-	option = (!stricmp(ival, on));
-}
-
-const char *PLAINFootnotes::getOptionValue()
-{
-	return (option) ? on:off;
-}
-
-
-char PLAINFootnotes::ProcessText(char *text, int maxlen, const SWKey *key, const SWModule *module)
-{
-	char token[2048];
-	int tokpos = 0;
-	bool intoken 	= false;
-	bool lastspace = false;
-
+char PLAINFootnotes::processText(SWBuf &text, const SWKey *key, const SWModule *module) {
 	if (!option) {	// if we don't want footnotes
-		char *to, *from;
-		int len;
+		//char token[2048];
+		//SWBuf token;
+		//int tokpos = 0;
+		//bool intoken 	= false;
+		//bool lastspace = false;
+
 		bool hide = false;
 
-		len = strlen(text) + 1;	// shift string to right of buffer
-		if (len < maxlen)
-		{
-			memmove(&text[maxlen - len], text, len);
-			from = &text[maxlen - len];
-		}
-		else	from = text;	// -------------------------------
-
-		for (to = text; *from; from++) {
-			if (*from == '{') // Footnote start
+		SWBuf orig = text;
+		const char *from = orig.c_str();
+		for (text = ""; *from; from++) {
+		 	if (*from == '{') // Footnote start
 			{
 				hide = true;
 				continue;
 			}
-			if (*from == '}') // Footnote end
+			else if (*from == '}') // Footnote end
 			{
-				hide=false;
+				hide = false;
 				continue;
 			}
-			if (intoken) {
-				if (tokpos < 2045)
-					token[tokpos++] = *from;
-					token[tokpos+2] = 0;
-			}
-			else	{
+			
+			//if (intoken) {
+				//if (tokpos < 2045)
+			//		token += *from;
+				//	token[tokpos+2] = 0;
+			//}
+			//else	{
 				if (!hide) {
-					*to++ = *from;
-					lastspace = (*from == ' ');
+					text = *from;
+					//lastspace = (*from == ' ');
 				}
-			}
+			//}
 		}
-		*to++ = 0;
-		*to = 0;
 	}
 	return 0;
 }
