@@ -1,16 +1,16 @@
 /******************************************************************************
  *
- * thmlstrongs -	SWFilter decendant to hide or show strongs number
+ * thmlstrongs -	SWFilter descendant to hide or show strongs number
  *			in a ThML module.
  */
 
 
 #include <stdlib.h>
 #include <stdio.h>
-#include <string>
 #include <stdarg.h>
 #include <thmlosis.h>
 #include <swmodule.h>
+#include <swlog.h>
 #include <versekey.h>
 #include <stdarg.h>
 #ifndef __GNUC__
@@ -28,9 +28,11 @@ ThMLOSIS::~ThMLOSIS() {
 }
 
 
-char ThMLOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWModule *module) {
+char ThMLOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module) {
+	/*
 
-	char *to, *from, token[2048]; // cheese.  Fix.
+	const char *from;
+	char token[2048]; // cheese.  Fix.
 	int tokpos = 0;
 	bool intoken = false;
 	int len;
@@ -45,23 +47,20 @@ char ThMLOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWMod
 	char *wordStart, *wordEnd;
 	bool newText = false;
 	bool newWord = false;
-	std::string tmp;
+	SWBuf tmp;
 	bool suspendTextPassThru = false;
 	bool keepToken = false;
+	bool handled = false;
+	SWBuf divEnd = "";
+
 
-	len = strlen(text) + 1;	// shift string to right of buffer
-	if (len < maxlen) {
-		memmove(&text[maxlen - len], text, len);
-		from = &text[maxlen - len];
-	}
-	else	from = text;
-	
-	textStart = from;
 	wordStart = text;
 
-	// -------------------------------
+	SWBuf orig = text;
+	from = orig.c_str();
+
+	for (text = ""; *from; from++) {
 
-	for (to = text; *from; from++) {
 		if (*from == '<') {
 			intoken = true;
 			tokpos = 0;
@@ -77,7 +76,7 @@ char ThMLOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWMod
 			keepToken = false;
 			suspendTextPassThru = false;
 			newWord = true;
-
+			handled = false;
 
 			while (wordStart < (text+maxlen)) {
 //				if (strchr(" ,;.?!()'\"", *wordStart))
@@ -91,57 +90,116 @@ char ThMLOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWMod
 				else break;
 			}
 
+			// section titles
+			if (!strcmp(token, "div class=\"sechead\"")) {
+				pushString(&to, "<title>");
+				divEnd = "</title>";
+				newText = true;
+				lastspace = false;
+				handled = true;
+			}
+			else	if (!strcmp(token, "/div")) {
+				pushString(&to, divEnd.c_str());
+				lastspace = false;
+				handled = true;
+			}
 			// Scripture Reference
 			if (!strncmp(token, "scripRef", 8)) {
 	//			pushString(buf, "<reference osisRef=\"");
 				suspendTextPassThru = true;
 				newText = true;
+				handled = true;
 			}
 			else	if (!strncmp(token, "/scripRef", 9)) {
 				tmp = "";
 				tmp.append(textStart, (int)(textEnd - textStart)+1);
 				pushString(&to, convertToOSIS(tmp.c_str(), key));
 				suspendTextPassThru = false;
+				handled = true;
 			}
+//      Usage of italics to represent transChange isn't domaninant;
+//        solution: mark in OSIS instead, assume no semantics other than emphasis
+//                of italicized text
+//                        if (!strcmp(module->Type(), "Biblical Texts")) {
+//        			// Italics assume transchange for Biblical texts
+//	        		if (!stricmp(token, "i")) {
+//		        		pushString(&to, "<transChange type=\"added\">");
+//			        	newText = true;
+//				        lastspace = false;
+//        				handled = true;
+//	        		}
+//		        	else	if (!stricmp(token, "/i")) {
+//			        	pushString(&to, "</transChange>");
+//        				lastspace = false;
+//	        			handled = true;
+//		        	}
+//                        }
+//                        else {
+//                        	// otherwise, italics are just italics
+//-- end italics for transchange
+	        		if (!stricmp(token, "i")) {
+		        		pushString(&to, "<hi type=\"i\">");
+			        	newText = true;
+				        lastspace = false;
+        				handled = true;
+	        		}
+		        	else	if (!stricmp(token, "/i")) {
+			        	pushString(&to, "</hi>");
+        				lastspace = false;
+	        			handled = true;
+		        	}
+//                        }
+
+	        	if (!strcmp(token, "b")) {
+		        	pushString(&to, "<hi type=\"b\">");
+			       	newText = true;
+			        lastspace = false;
+        			handled = true;
+	        	}
+		        else	if (!strcmp(token, "/b")) {
+			       	pushString(&to, "</hi>");
+        			lastspace = false;
+	        		handled = true;
+                        }
 
 			// Footnote
 			if (!strcmp(token, "note")) {
-	//			pushString(buf, "<reference work=\"Bible.KJV\" reference=\"");
-				suspendTextPassThru = true;
+		        	pushString(&to, "<note>");
 				newText = true;
+                                lastspace = false;
+				handled = true;
 			}
 			else	if (!strcmp(token, "/note")) {
-				tmp = "<note type=\"x-StudyNote\"><notePart type=\"x-MainText\">";
-				tmp.append(textStart, (int)(textEnd - textStart)+1);
-				tmp += "</notePart></note>";
-				pushString(&to, tmp.c_str());
-				suspendTextPassThru = false;
+				pushString(&to, "</note>");
+                                lastspace = false;
+				handled = true;
 			}
 
 			// Figure
 			else	if (!strncmp(token, "img ", 4)) {
 				const char *src = strstr(token, "src");
 				if (!src)		// assert we have a src attribute
-					return false;
+					continue;
+//					return false;
 
 				pushString(&to, "<figure src=\"");
 				const char *c;
 				for (c = src;((*c) && (*c != '"')); c++);
 
-				/* uncomment for SWORD absolute path logic
-				if (*(c+1) == '/') {
-					pushString(buf, "file:");
-					pushString(buf, module->getConfigEntry("AbsoluteDataPath"));
-					if (*((*buf)-1) == '/')
-						c++;		// skip '/'
-				}
-				end of uncomment for asolute path logic */
+// uncomment for SWORD absolute path logic
+//				if (*(c+1) == '/') {
+//					pushString(buf, "file:");
+//					pushString(buf, module->getConfigEntry("AbsoluteDataPath"));
+//					if (*((*buf)-1) == '/')
+//						c++;		// skip '/'
+//				}
+//				end of uncomment for asolute path logic 
 
 				for (c++;((*c) && (*c != '"')); c++)
 					*to++ = *c;
 
 				pushString(&to, "\" />");
-				return true;
+				handled = true;
 			}
 
 			// Strongs numbers
@@ -170,6 +228,7 @@ char ThMLOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWMod
 						module->getEntryAttributes()["Word"][wordstr]["Morph"] = val;
 					}
 				}
+				handled = true;
 			}
 
 			// Morphology
@@ -209,9 +268,14 @@ char ThMLOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWMod
 						to+=strlen(buf);
 					}
 				}
+				handled = true;
 			}
 
 			if (!keepToken) {	// if we don't want strongs
+				if (!handled) {
+					SWLog::systemlog->LogError("Unprocessed Token: <%s>", token);
+//					exit(-1);
+				}
 				if (strchr(" ,:;.?!()'\"", from[1])) {
 					if (lastspace)
 						to--;
@@ -248,11 +312,7 @@ char ThMLOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWMod
 	if (vkey) {
 		char ref[254];
 		if (vkey->Verse())
-			sprintf(ref, "\t\t<verse osisID=\"%s\">", vkey->getOSISRef());
-		else if (vkey->Chapter())
-			sprintf(ref, "\t<div type=\"chapter\" osisID=\"%s\">", vkey->getOSISRef());
-		else if (vkey->Book())
-			sprintf(ref, "\t<div type=\"book\" osisID=\"%s\">", vkey->getOSISRef());
+			sprintf(ref, "<verse osisID=\"%s\">", vkey->getOSISRef());
 		else *ref = 0;
 		if (*ref) {
 			memmove(text+strlen(ref), text, maxlen-strlen(ref)-1);
@@ -268,43 +328,33 @@ char ThMLOSIS::ProcessText(char *text, int maxlen, const SWKey *key, const SWMod
 				tmp = MAXVERSE;
 				if (*vkey == tmp) {
 					tmp.Verse(0);
-					sprintf(ref, "\t</div>");
-					pushString(&to, ref);
+//					sprintf(ref, "\t</div>");
+//					pushString(&to, ref);
 					tmp = MAXCHAPTER;
 					tmp = MAXVERSE;
 					if (*vkey == tmp) {
 						tmp.Chapter(0);
 						tmp.Verse(0);
-						sprintf(ref, "\t</div>");
-						pushString(&to, ref);
+//						sprintf(ref, "\t</div>");
+//						pushString(&to, ref);
 					}
 				}
 			}
 
-			else if (vkey->Chapter())
-				sprintf(ref, "\t<div type=\"chapter\" osisID=\"%s\">", vkey->getOSISRef());
-			else sprintf(ref, "\t<div type=\"book\" osisID=\"%s\">", vkey->getOSISRef());
+//			else if (vkey->Chapter())
+//				sprintf(ref, "\t<div type=\"chapter\" osisID=\"%s\">", vkey->getOSISRef());
+//			else sprintf(ref, "\t<div type=\"book\" osisID=\"%s\">", vkey->getOSISRef());
 		}
 	}
 	*to++ = 0;
 	*to = 0;
+*/
 	return 0;
 }
 
 
-void ThMLOSIS::pushString(char **buf, const char *format, ...) {
-  va_list argptr;
-
-  va_start(argptr, format);
-  *buf += vsprintf(*buf, format, argptr);
-  va_end(argptr);
-
-//  *buf += strlen(*buf);
-}
-
-
 const char *ThMLOSIS::convertToOSIS(const char *inRef, const SWKey *key) {
-	static std::string outRef;
+	static SWBuf outRef;
 
 	outRef = "";
 
