@@ -16,7 +16,6 @@
 SWORD_NAMESPACE_START
 
 SWDisplay SWModule::rawdisp;
-void SWModule::nullPercent(char percent, void *percentUserData) {}
 
 /******************************************************************************
  * SWModule Constructor - Initializes data for instance of SWModule
@@ -128,11 +127,14 @@ char SWModule::Error()
  * RET:	pointer to modname
  */
 
-char *SWModule::Name(const char *imodname)
-{
+char *SWModule::Name(const char *imodname) {
 	return stdstr(&modname, imodname);
 }
 
+char *SWModule::Name() const {
+	return modname;
+}
+
 
 /******************************************************************************
  * SWModule::Description - Sets/gets module description
@@ -143,11 +145,14 @@ char *SWModule::Name(const char *imodname)
  * RET:	pointer to moddesc
  */
 
-char *SWModule::Description(const char *imoddesc)
-{
+char *SWModule::Description(const char *imoddesc) {
 	return stdstr(&moddesc, imoddesc);
 }
 
+char *SWModule::Description() const {
+	return moddesc;
+}
+
 
 /******************************************************************************
  * SWModule::Type - Sets/gets module type
@@ -158,11 +163,14 @@ char *SWModule::Description(const char *imoddesc)
  * RET:	pointer to modtype
  */
 
-char *SWModule::Type(const char *imodtype)
-{
+char *SWModule::Type(const char *imodtype) {
 	return stdstr(&modtype, imodtype);
 }
 
+char *SWModule::Type() const {
+	return modtype;
+}
+
 /******************************************************************************
  * SWModule::Direction - Sets/gets module direction
  *
@@ -358,6 +366,7 @@ void SWModule::decrement(int steps) {
  *				>=0 - regex
  *				-1  - phrase
  *				-2  - multiword
+ *				-3  - entryAttrib
  * 	flags		- options flags for search
  *	justCheckIfSupported	- if set, don't search, only tell if this
  *							function supports requested search.
@@ -365,8 +374,7 @@ void SWModule::decrement(int steps) {
  * RET: listkey set to verses that contain istr
  */
 
-ListKey &SWModule::Search(const char *istr, int searchType, int flags, SWKey *scope, bool *justCheckIfSupported, void (*percent)(char, void *), void *percentUserData)
-{
+ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *scope, bool *justCheckIfSupported, void (*percent)(char, void *), void *percentUserData) {
 	SWKey *savekey = 0;
 	SWKey *searchkey = 0;
 	regex_t preg;
@@ -379,7 +387,8 @@ ListKey &SWModule::Search(const char *istr, int searchType, int flags, SWKey *sc
 	char perc = 1;
 	bool savePEA = isProcessEntryAttributes();
 
-	processEntryAttributes(false);
+	processEntryAttributes(searchType == -3);
+	
 	listkey.ClearList();
 
 	if (!key->Persist()) {
@@ -437,6 +446,32 @@ ListKey &SWModule::Search(const char *istr, int searchType, int flags, SWKey *sc
 		}
 	}
 
+	if (searchType == -3) {
+		wordBuf = (char *)calloc(sizeof(char), strlen(istr) + 1);
+		char *checkSlash = wordBuf;
+		strcpy(wordBuf, istr);
+		words = (char **)calloc(sizeof(char *), 10);
+		int allocWords = 10;
+		while (*checkSlash == '/')
+			words[wordCount++] = checkSlash++;
+		words[wordCount] = strtok(wordBuf, "/");
+		while (words[wordCount]) {
+			wordCount++;
+			if (wordCount == allocWords) {
+				allocWords+=10;
+				words = (char **)realloc(words, sizeof(char *)*allocWords);
+			}
+			checkSlash = words[wordCount-1] + (strlen(words[wordCount-1]))+1;
+			while (*checkSlash == '/')
+				words[wordCount++] = checkSlash++;
+			words[wordCount] = strtok(NULL, "/");
+		}
+		for (int i = 0; i < wordCount; i++) {
+			if (words[i][0] == '/')
+				words[i][0] = 0;
+		}
+	}
+
 	perc = 5;
 	(*percent)(perc, percentUserData);
 
@@ -472,27 +507,79 @@ ListKey &SWModule::Search(const char *istr, int searchType, int flags, SWKey *sc
 				listkey << textkey;
 			}
 		}
-		else {
-			if (searchType == -1) {
-				sres = ((flags & REG_ICASE) == REG_ICASE) ? stristr(StripText(), istr) : strstr(StripText(), istr);
-				if (sres) {
-						textkey = KeyText();
-						listkey << textkey;
-				}
-			}
-			if (searchType == -2) {
-				int i;
-				const char *stripBuf = StripText();
-				for (i = 0; i < wordCount; i++) {
-					sres = ((flags & REG_ICASE) == REG_ICASE) ? stristr(stripBuf, words[i]) : strstr(stripBuf, words[i]);
-					if (!sres)
-						break;
-				}
-				if (i == wordCount) {
+		else if (searchType == -1) {
+			sres = ((flags & REG_ICASE) == REG_ICASE) ? stristr(StripText(), istr) : strstr(StripText(), istr);
+			if (sres) {
 					textkey = KeyText();
 					listkey << textkey;
-				}
+			}
+		}
+		else if (searchType == -2) {
+			int i;
+			const char *stripBuf = StripText();
+			for (i = 0; i < wordCount; i++) {
+				sres = ((flags & REG_ICASE) == REG_ICASE) ? stristr(stripBuf, words[i]) : strstr(stripBuf, words[i]);
+				if (!sres)
+					break;
+			}
+			if (i == wordCount) {
+				textkey = KeyText();
+				listkey << textkey;
+			}
+		}
+		else if (searchType == -3) {
+			int i;
+			RenderText();	// force parse
+			AttributeTypeList &entryAttribs = getEntryAttributes();
+			AttributeTypeList::iterator i1Start, i1End;
+			AttributeList::iterator i2Start, i2End;
+			AttributeValue::iterator i3Start, i3End;
 
+			if ((words[0]) && (words[0][0])) {
+				i1Start = entryAttribs.find(words[0]);
+				i1End = i1Start;
+				if (i1End != entryAttribs.end())
+				i1End++;
+			}
+			else {
+				i1Start = entryAttribs.begin();
+				i1End   = entryAttribs.end();
+			}
+			for (;i1Start != i1End; i1Start++) {
+				if ((words[1]) && (words[1][0])) {
+					i2Start = i1Start->second.find(words[1]);
+					i2End = i2Start;
+					if (i2End != i1Start->second.end())
+						i2End++;
+				}
+				else {
+					i2Start = i1Start->second.begin();
+					i2End   = i1Start->second.end();
+				}
+				for (;i2Start != i2End; i2Start++) {
+					if ((words[2]) && (words[2][0])) {
+						i3Start = i2Start->second.find(words[2]);
+						i3End = i3Start;
+						if (i3End != i2Start->second.end())
+							i3End++;
+					}
+					else {
+						i3Start = i2Start->second.begin();
+						i3End   = i2Start->second.end();
+					}
+					for (;i3Start != i3End; i3Start++) {
+						sres = ((flags & REG_ICASE) == REG_ICASE) ? stristr(i3Start->second.c_str(), words[3]) : strstr(i3Start->second.c_str(), words[3]);
+						if (sres) {
+							textkey = KeyText();
+							listkey << textkey;
+							break;
+						}
+					}
+					if (i3Start != i3End)
+						break;
+				}
+				if (i2Start != i2End)
+					break;
 			}
 		}
 		(*this)++;
