@@ -3,7 +3,9 @@
 #include <stdlib.h>
 #include <listkey.h>
 #include <versekey.h>
-
+#ifndef NO_SWORD_NAMESPACE
+using namespace sword;
+#endif
 
 int main(int argc, char **argv)
 {
