@@ -1,6 +1,9 @@
 #include <swmgr.h>
 #include <iostream>
 #include <versekey.h>
+#ifndef NO_SWORD_NAMESPACE
+using namespace sword;
+#endif
 
 int main(int argc, char **argv) {
 	SWMgr::debug = true;
@@ -26,6 +29,5 @@ int main(int argc, char **argv) {
 		for (mhc->Key("Gen 1:1"); mhc->Key() < (VerseKey) "Gen 1:10"; (*mhc)++)
 			std::cout << (const char *) *mhc << "\n";
 	}
-	cin >> keypress;
 	return 0;
 }
