@@ -9,12 +9,12 @@ using namespace sword;
 #endif
 
 int main(int argc, char **argv) {
-	if ((argc != 2) && (argc != 3)) {
-		fprintf(stderr, "usage: %s <\"string to parse\"> [locale name]\n", *argv);
+	if ((argc < 2) || (argc > 4)) {
+		fprintf(stderr, "usage: %s <\"string to parse\"> [locale name] [test-in-set-verse]\n", *argv);
 		exit(-1);
 	}
 
-	if (argc == 3)
+	if (argc > 2)
 		LocaleMgr::systemLocaleMgr.setDefaultLocaleName(argv[2]);
 
 	VerseKey DefaultVSKey;
@@ -26,12 +26,18 @@ int main(int argc, char **argv) {
 	for (int i = 0; i < verses.Count(); i++) {
 		VerseKey *element = dynamic_cast<VerseKey *>(verses.GetElement(i));
 		if (element) {
-			std::cout << (std::string(element->LowerBound()) + " - " + std::string(element->UpperBound())).c_str() << "\n";
+			std::cout << (SWBuf(element->LowerBound()) + " - " + SWBuf(element->UpperBound())).c_str() << "\n";
 		}
 		else	std::cout << (const char *)*verses.GetElement(i) << "\n";
 //		else	{
 //			std::cout << VerseKey(verses.GetElement(i)).getOSISRef() << "\n";
 //		}
 	}
+
+	if (argc > 3) {
+		verses.setText(argv[3]);
+		std::cout << "Verse is" << ((verses.Error()) ? " NOT" : "") << " in set.\n\n";
+	}
+
 	return 0;
 }
