@@ -1,5 +1,5 @@
 #include <stdio.h>
-#include <iostream.h>
+#include <iostream>
 #include <versekey.h>
 #include <rawtext.h>
 #include <zcom.h>
@@ -27,7 +27,7 @@ int main(int argc, char **argv)
 
 	mykey = argv[2];
 	mykey.Persist(1);
-	personal.SetKey(mykey);
+	personal.setKey(mykey);
 
 	max = (argc < 4) ? 1 : atoi(argv[3]);
 
@@ -35,6 +35,6 @@ int main(int argc, char **argv)
 		personal << argv[1];
 		mykey++;
 	}
-	cout << "Added Comment\n";
+	std::cout << "Added Comment" << std::endl;
 	return 0;
 }
