@@ -14,6 +14,14 @@
 #include <rawtext.h>
 #include <iostream>
 
+#ifndef NO_SWORD_NAMESPACE
+using sword::SWMgr;
+using sword::RawText;
+using sword::SWKey;
+using sword::VerseKey;
+using sword::ListKey;
+using sword::SWModule;
+#endif
 
 #ifndef O_BINARY
 #define O_BINARY 0
@@ -73,7 +81,7 @@ int main(int argc, char **argv) {
 	if (element) {
 	  mod->Key(element->LowerBound());
 	  VerseKey finalkey = element->UpperBound();
-	  std::cout << (const char*)mod->Key() << "-" << (const char*)finalkey << endl;
+	  std::cout << (const char*)mod->Key() << "-" << (const char*)finalkey << std::endl;
 	  if (!havefirst) {
 	    havefirst = true;
 	    firstverse = mod->Key();
@@ -87,11 +95,11 @@ int main(int argc, char **argv) {
 	    entrysize = fread(buffer, sizeof(char), sizeof(buffer), infile);
 	    
 	    mod->setEntry(buffer, entrysize);	// save text to module at current position
-	    std::cout << "f" << (const char*)firstverse << endl;
+	    std::cout << "f" << (const char*)firstverse << std::endl;
 	    (*mod)++;
 	  }
 	  while (mod->Key() <= finalkey) {
-	    std::cout << (const char*)mod->Key() << endl;
+	    std::cout << (const char*)mod->Key() << std::endl;
 	    *(SWModule*)mod << &firstverse;
 	    (*mod)++;
 	  }
@@ -100,7 +108,7 @@ int main(int argc, char **argv) {
 	  if (havefirst) {
 	    mod->Key(*listkey.GetElement(i));
 	    *(SWModule*)mod << &firstverse;
-	    std::cout << (const char*)mod->Key() << endl;
+	    std::cout << (const char*)mod->Key() << std::endl;
 	  }
 	  else {
 	    mod->Key(*listkey.GetElement(i));
@@ -116,7 +124,7 @@ int main(int argc, char **argv) {
 	    entrysize = fread(buffer, sizeof(char), sizeof(buffer), infile);
 	    
 	    mod->setEntry(buffer, entrysize);	// save text to module at current position
-	    std::cout << "f" << (const char*)firstverse << endl;
+	    std::cout << "f" << (const char*)firstverse << std::endl;
 	  }
 	}
       }
