@@ -14,10 +14,9 @@
 #include <swcipher.h>
 #include <versekey.h>
 #include <rawverse.h>
+#include <swbuf.h>
 #ifndef NO_SWORD_NAMESPACE
-using sword::SWCipher;
-using sword::VerseKey;
-using sword::RawVerse;
+using namespace sword;
 #endif
 
 int main(int argc, char **argv) {
@@ -63,7 +62,7 @@ int main(int argc, char **argv) {
 	key.AutoNormalize(0);
 	key.Headings(1);
 	for (key.Index(0); (!key.Error()); key++) {
-		rawdrv->findoffset(key.Testament(), key.Index(), &offset, &size);
+		rawdrv->findOffset(key.Testament(), key.Index(), &offset, &size);
 		printf("%s: OLD offset: %d; size: %d\n", (const char *)key, offset, size);
 
 		if ((offset == loffset) && (size == lsize)) {
@@ -78,18 +77,21 @@ int main(int argc, char **argv) {
 			loffset = offset;
 
 			if (size) {
-				tmpbuf = (char *) calloc(size + 2, 1);
-				rawdrv->readtext(key.Testament(), offset, size + 2, tmpbuf);
-				zobj->Buf(tmpbuf, size);
-				zobj->cipherBuf((unsigned int *)&size);
-				free(tmpbuf);
+				SWBuf tmpbuf;
+				rawdrv->readText(key.Testament(), offset, size, tmpbuf);
+				zobj->Buf(tmpbuf.c_str(), size);
+				unsigned long ulSize = size;
+				zobj->cipherBuf(&ulSize);
+				size = (unsigned int)ulSize;
 			}
 			offset = lseek(ofd[key.Testament() - 1], 0, SEEK_CUR);
 			tmpoff = lseek(oxfd[key.Testament() - 1], 0, SEEK_CUR);
 			printf("%s: (%ld) NEW offset: %ld; size: %d\n", (const char *)key, tmpoff, offset, size);
 			write(oxfd[key.Testament() - 1], &offset, 4);
+			unsigned long ulSize = size;
 			if (size) 
-				write(ofd[key.Testament() - 1], zobj->cipherBuf((unsigned int *)&size), size);
+				write(ofd[key.Testament() - 1], zobj->cipherBuf(&ulSize), size);
+			size = (unsigned int)ulSize;
 			lzoffset = offset;
 			write(oxfd[key.Testament() - 1], &size, 2);
 			lzsize = size;
