@@ -1,6 +1,14 @@
 #include <swmgr.h>
 #include <versekey.h>
 #include <iostream>
+#ifndef NO_SWORD_NAMESPACE
+using sword::SWMgr;
+using sword::VerseKey;
+using sword::SWModule;
+using sword::SWKey;
+using sword::SW_POSITION;
+using sword::ModMap;
+#endif
 
 void cleanbuf(char *buf) {
 	char *from = buf;
