@@ -3,7 +3,7 @@
 #include <fcntl.h>
 #include <iostream>
 #include <fstream>
-#include <string>
+//#include <string>
 
 #ifndef __GNUC__
 #include <io.h>
@@ -14,6 +14,14 @@
 #include <swmgr.h>
 #include <stdio.h>
 
+#ifndef NO_SWORD_NAMESPACE
+using sword::SWMgr;
+using sword::SWModule;
+using sword::ModMap;
+using sword::SWKey;
+#endif
+
+using std::cerr;
 
 int main(int argc, char **argv)
 {
